import flags
import numpy
import pydrake.autodiffutils
import pydrake.common
import pydrake.common.eigen_geometry
import pydrake.math
import pydrake.polynomial
import pydrake.symbolic
import scipy.sparse
from pydrake.common.cpp_template import BezierCurve_ as BezierCurve_, BsplineTrajectory_ as BsplineTrajectory_, CompositeTrajectory_ as CompositeTrajectory_, DerivativeTrajectory_ as DerivativeTrajectory_, DiscreteTimeTrajectory_ as DiscreteTimeTrajectory_, ExponentialPlusPiecewisePolynomial_ as ExponentialPlusPiecewisePolynomial_, FunctionHandleTrajectory_ as FunctionHandleTrajectory_, PathParameterizedTrajectory_ as PathParameterizedTrajectory_, PiecewisePolynomial_ as PiecewisePolynomial_, PiecewisePose_ as PiecewisePose_, PiecewiseQuaternionSlerp_ as PiecewiseQuaternionSlerp_, PiecewiseTrajectory_ as PiecewiseTrajectory_, StackedTrajectory_ as StackedTrajectory_, Trajectory_ as Trajectory_
from typing import Any, Callable, ClassVar, overload

__getattr__: Callable

class BezierCurve(Trajectory):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, start_time: float, end_time: float, control_points: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def AsLinearInControlPoints(self, derivative_order: int = ...) -> scipy.sparse.csc_matrix[numpy.float64]: ...
    @overload
    def AsLinearInControlPoints(self, n) -> Any: ...
    def BernsteinBasis(self, i: int, time: float, order: int | None = ...) -> float: ...
    def ElevateOrder(self) -> None: ...
    def GetExpression(self, time: pydrake.symbolic.Variable = ...) -> numpy.ndarray[object[m, 1]]: ...
    def control_points(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def order(self) -> int: ...
    def __copy__(self) -> BezierCurve: ...
    def __deepcopy__(self, arg0: dict) -> BezierCurve: ...

class BezierCurve_𝓣AutoDiffXd𝓤(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, start_time: float, end_time: float, control_points: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def BernsteinBasis(self, i: int, time: pydrake.autodiffutils.AutoDiffXd, order: int | None = ...) -> pydrake.autodiffutils.AutoDiffXd: ...
    def ElevateOrder(self) -> None: ...
    def GetExpression(self, time: pydrake.symbolic.Variable = ...) -> numpy.ndarray[object[m, 1]]: ...
    def control_points(self) -> numpy.ndarray[object[m, n]]: ...
    def order(self) -> int: ...
    def __copy__(self) -> BezierCurve_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> BezierCurve_TAutoDiffXdU: ...

class BezierCurve_𝓣Expression𝓤(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, start_time: float, end_time: float, control_points: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def BernsteinBasis(self, i: int, time: pydrake.symbolic.Expression, order: int | None = ...) -> pydrake.symbolic.Expression: ...
    def ElevateOrder(self) -> None: ...
    def GetExpression(self, time: pydrake.symbolic.Variable = ...) -> numpy.ndarray[object[m, 1]]: ...
    def control_points(self) -> numpy.ndarray[object[m, n]]: ...
    def order(self) -> int: ...
    def __copy__(self) -> BezierCurve_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> BezierCurve_TExpressionU: ...

class BsplineTrajectory(Trajectory):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, basis: pydrake.math.BsplineBasis, control_points: list[list[float]]) -> None: ...
    @overload
    def __init__(self, basis: pydrake.math.BsplineBasis, control_points: list[numpy.ndarray[numpy.float64[m, n]]]) -> None: ...
    def AsLinearInControlPoints(self, derivative_order: int = ...) -> scipy.sparse.csc_matrix[numpy.float64]: ...
    def CopyBlock(self, start_row: int, start_col: int, block_rows: int, block_cols: int) -> BsplineTrajectory: ...
    def CopyHead(self, n: int) -> BsplineTrajectory: ...
    def EvaluateLinearInControlPoints(self, parameter_value: float, derivative_order: int = ...) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def FinalValue(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def InitialValue(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def InsertKnots(self, additional_knots: list[float]) -> None: ...
    def basis(self) -> pydrake.math.BsplineBasis: ...
    def control_points(self) -> list[numpy.ndarray[numpy.float64[m, n]]]: ...
    def num_control_points(self) -> int: ...
    def __copy__(self) -> BsplineTrajectory: ...
    def __deepcopy__(self, arg0: dict) -> BsplineTrajectory: ...

class BsplineTrajectory_𝓣AutoDiffXd𝓤(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, basis: pydrake.math.BsplineBasis_TAutoDiffXdU, control_points: list[list[pydrake.autodiffutils.AutoDiffXd]]) -> None: ...
    @overload
    def __init__(self, basis: pydrake.math.BsplineBasis_TAutoDiffXdU, control_points: list[numpy.ndarray[object[m, n]]]) -> None: ...
    def CopyBlock(self, start_row: int, start_col: int, block_rows: int, block_cols: int) -> BsplineTrajectory_TAutoDiffXdU: ...
    def CopyHead(self, n: int) -> BsplineTrajectory_TAutoDiffXdU: ...
    def EvaluateLinearInControlPoints(self, parameter_value: pydrake.autodiffutils.AutoDiffXd, derivative_order: int = ...) -> numpy.ndarray[object[m, 1]]: ...
    def FinalValue(self) -> numpy.ndarray[object[m, n]]: ...
    def InitialValue(self) -> numpy.ndarray[object[m, n]]: ...
    def InsertKnots(self, additional_knots: list[pydrake.autodiffutils.AutoDiffXd]) -> None: ...
    def basis(self) -> pydrake.math.BsplineBasis_TAutoDiffXdU: ...
    def control_points(self) -> list[numpy.ndarray[object[m, n]]]: ...
    def num_control_points(self) -> int: ...
    def __copy__(self) -> BsplineTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> BsplineTrajectory_TAutoDiffXdU: ...

class BsplineTrajectory_𝓣Expression𝓤(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, basis: pydrake.math.BsplineBasis_TExpressionU, control_points: list[list[pydrake.symbolic.Expression]]) -> None: ...
    @overload
    def __init__(self, basis: pydrake.math.BsplineBasis_TExpressionU, control_points: list[numpy.ndarray[object[m, n]]]) -> None: ...
    def CopyBlock(self, start_row: int, start_col: int, block_rows: int, block_cols: int) -> BsplineTrajectory_TExpressionU: ...
    def CopyHead(self, n: int) -> BsplineTrajectory_TExpressionU: ...
    def EvaluateLinearInControlPoints(self, parameter_value: pydrake.symbolic.Expression, derivative_order: int = ...) -> numpy.ndarray[object[m, 1]]: ...
    def FinalValue(self) -> numpy.ndarray[object[m, n]]: ...
    def InitialValue(self) -> numpy.ndarray[object[m, n]]: ...
    def InsertKnots(self, additional_knots: list[pydrake.symbolic.Expression]) -> None: ...
    def basis(self) -> pydrake.math.BsplineBasis_TExpressionU: ...
    def control_points(self) -> list[numpy.ndarray[object[m, n]]]: ...
    def num_control_points(self) -> int: ...
    def __copy__(self) -> BsplineTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> BsplineTrajectory_TExpressionU: ...

class CompositeTrajectory(PiecewiseTrajectory):
    def __init__(self, segments: list[Trajectory]) -> None: ...
    @staticmethod
    def AlignAndConcatenate(segments: list[Trajectory]) -> CompositeTrajectory: ...
    def segment(self, segment_index: int) -> Trajectory: ...
    def __copy__(self) -> CompositeTrajectory: ...
    def __deepcopy__(self, arg0: dict) -> CompositeTrajectory: ...

class CompositeTrajectory_𝓣AutoDiffXd𝓤(PiecewiseTrajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, segments: list[Trajectory_TAutoDiffXdU]) -> None: ...
    @staticmethod
    def AlignAndConcatenate(segments: list[Trajectory_TAutoDiffXdU]) -> CompositeTrajectory_TAutoDiffXdU: ...
    def segment(self, segment_index: int) -> Trajectory_TAutoDiffXdU: ...
    def __copy__(self) -> CompositeTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> CompositeTrajectory_TAutoDiffXdU: ...

class CompositeTrajectory_𝓣Expression𝓤(PiecewiseTrajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, segments: list[Trajectory_TExpressionU]) -> None: ...
    @staticmethod
    def AlignAndConcatenate(segments: list[Trajectory_TExpressionU]) -> CompositeTrajectory_TExpressionU: ...
    def segment(self, segment_index: int) -> Trajectory_TExpressionU: ...
    def __copy__(self) -> CompositeTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> CompositeTrajectory_TExpressionU: ...

class DerivativeTrajectory(Trajectory):
    def __init__(self, nominal: Trajectory, derivative_order: int = ...) -> None: ...
    def __copy__(self) -> DerivativeTrajectory: ...
    def __deepcopy__(self, arg0: dict) -> DerivativeTrajectory: ...

class DerivativeTrajectory_𝓣AutoDiffXd𝓤(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, nominal: Trajectory_TAutoDiffXdU, derivative_order: int = ...) -> None: ...
    def __copy__(self) -> DerivativeTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> DerivativeTrajectory_TAutoDiffXdU: ...

class DerivativeTrajectory_𝓣Expression𝓤(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, nominal: Trajectory_TExpressionU, derivative_order: int = ...) -> None: ...
    def __copy__(self) -> DerivativeTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> DerivativeTrajectory_TExpressionU: ...

class DiscreteTimeTrajectory(Trajectory):
    def __init__(self, times: list[float], values: list[numpy.ndarray[numpy.float64[m, n]]], time_comparison_tolerance: float = ...) -> None: ...
    def ToZeroOrderHold(self) -> PiecewisePolynomial: ...
    def get_times(self) -> list[float]: ...
    def num_times(self) -> int: ...
    def time_comparison_tolerance(self) -> float: ...
    def __copy__(self) -> DiscreteTimeTrajectory: ...
    def __deepcopy__(self, arg0: dict) -> DiscreteTimeTrajectory: ...

class DiscreteTimeTrajectory_𝓣AutoDiffXd𝓤(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, times: list[pydrake.autodiffutils.AutoDiffXd], values: list[numpy.ndarray[object[m, n]]], time_comparison_tolerance: float = ...) -> None: ...
    def ToZeroOrderHold(self) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def get_times(self) -> list[pydrake.autodiffutils.AutoDiffXd]: ...
    def num_times(self) -> int: ...
    def time_comparison_tolerance(self) -> float: ...
    def __copy__(self) -> DiscreteTimeTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> DiscreteTimeTrajectory_TAutoDiffXdU: ...

class DiscreteTimeTrajectory_𝓣Expression𝓤(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, times: list[pydrake.symbolic.Expression], values: list[numpy.ndarray[object[m, n]]], time_comparison_tolerance: float = ...) -> None: ...
    def ToZeroOrderHold(self) -> PiecewisePolynomial_TExpressionU: ...
    def get_times(self) -> list[pydrake.symbolic.Expression]: ...
    def num_times(self) -> int: ...
    def time_comparison_tolerance(self) -> float: ...
    def __copy__(self) -> DiscreteTimeTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> DiscreteTimeTrajectory_TExpressionU: ...

class ExponentialPlusPiecewisePolynomial(PiecewiseTrajectory):
    def __init__(self, K: numpy.ndarray[numpy.float64[m, n]], A: numpy.ndarray[numpy.float64[m, n]], alpha: numpy.ndarray[numpy.float64[m, n]], piecewise_polynomial_part: PiecewisePolynomial) -> None: ...
    def shiftRight(self, offset: float) -> None: ...
    def __copy__(self) -> ExponentialPlusPiecewisePolynomial: ...
    def __deepcopy__(self, arg0: dict) -> ExponentialPlusPiecewisePolynomial: ...

class FunctionHandleTrajectory(Trajectory):
    def __init__(self, func: Callable[[float], numpy.ndarray[numpy.float64[m, n]]], rows: int, cols: int = ..., start_time: float = ..., end_time: float = ...) -> None: ...
    def set_derivative(self, func: Callable[[float, int], numpy.ndarray[numpy.float64[m, n]]]) -> None: ...
    def __copy__(self) -> FunctionHandleTrajectory: ...
    def __deepcopy__(self, arg0: dict) -> FunctionHandleTrajectory: ...

class FunctionHandleTrajectory_𝓣AutoDiffXd𝓤(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, func: Callable[[pydrake.autodiffutils.AutoDiffXd], numpy.ndarray[object[m, n]]], rows: int, cols: int = ..., start_time: float = ..., end_time: float = ...) -> None: ...
    def set_derivative(self, func: Callable[[pydrake.autodiffutils.AutoDiffXd, int], numpy.ndarray[object[m, n]]]) -> None: ...
    def __copy__(self) -> FunctionHandleTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> FunctionHandleTrajectory_TAutoDiffXdU: ...

class FunctionHandleTrajectory_𝓣Expression𝓤(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, func: Callable[[pydrake.symbolic.Expression], numpy.ndarray[object[m, n]]], rows: int, cols: int = ..., start_time: float = ..., end_time: float = ...) -> None: ...
    def set_derivative(self, func: Callable[[pydrake.symbolic.Expression, int], numpy.ndarray[object[m, n]]]) -> None: ...
    def __copy__(self) -> FunctionHandleTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> FunctionHandleTrajectory_TExpressionU: ...

class PathParameterizedTrajectory(Trajectory):
    def __init__(self, path: Trajectory, time_scaling: Trajectory) -> None: ...
    def path(self) -> Trajectory: ...
    def time_scaling(self) -> Trajectory: ...
    def __copy__(self) -> PathParameterizedTrajectory: ...
    def __deepcopy__(self, arg0: dict) -> PathParameterizedTrajectory: ...

class PathParameterizedTrajectory_𝓣AutoDiffXd𝓤(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, path: Trajectory_TAutoDiffXdU, time_scaling: Trajectory_TAutoDiffXdU) -> None: ...
    def path(self) -> Trajectory_TAutoDiffXdU: ...
    def time_scaling(self) -> Trajectory_TAutoDiffXdU: ...
    def __copy__(self) -> PathParameterizedTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> PathParameterizedTrajectory_TAutoDiffXdU: ...

class PathParameterizedTrajectory_𝓣Expression𝓤(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, path: Trajectory_TExpressionU, time_scaling: Trajectory_TExpressionU) -> None: ...
    def path(self) -> Trajectory_TExpressionU: ...
    def time_scaling(self) -> Trajectory_TExpressionU: ...
    def __copy__(self) -> PathParameterizedTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> PathParameterizedTrajectory_TExpressionU: ...

class PiecewisePolynomial(PiecewiseTrajectory):
    __fields__: ClassVar[tuple] = ...  # read-only
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def __init__(self, arg0: list[numpy.ndarray[object[m, n]]], arg1: list[float]) -> None: ...
    @overload
    def __init__(self, arg0: list[pydrake.polynomial.Polynomial], arg1: list[float]) -> None: ...
    def AppendCubicHermiteSegment(self, time: float, sample: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous], sample_dot: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def AppendFirstOrderSegment(self, time: float, sample: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def Block(self, start_row: int, start_col: int, block_rows: int, block_cols: int) -> PiecewisePolynomial: ...
    def ConcatenateInTime(self, other: PiecewisePolynomial) -> None: ...
    @overload
    @staticmethod
    def CubicHermite(breaks: list[float], samples: list[list[float]], samples_dot: list[list[float]]) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def CubicHermite(breaks, samples, samples_dot) -> Any: ...
    @overload
    @staticmethod
    def CubicHermite(breaks: list[float], samples: list[numpy.ndarray[numpy.float64[m, n]]], samples_dot: list[numpy.ndarray[numpy.float64[m, n]]]) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def CubicShapePreserving(breaks: list[float], samples: list[list[float]], zero_end_point_derivatives: bool = ...) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def CubicShapePreserving(breaks: list[float], samples: list[numpy.ndarray[numpy.float64[m, n]]], zero_end_point_derivatives: bool = ...) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[float], samples: list[list[float]], sample_dot_at_start: numpy.ndarray[numpy.float64[m, n]], sample_dot_at_end: numpy.ndarray[numpy.float64[m, n]]) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives() -> Any: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[float], samples: list[numpy.ndarray[numpy.float64[m, n]]], sample_dot_at_start: numpy.ndarray[numpy.float64[m, n]], sample_dot_at_end: numpy.ndarray[numpy.float64[m, n]]) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[float], samples: list[list[float]], periodic_end_condition: bool = ...) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[float], samples: list[numpy.ndarray[numpy.float64[m, n]]], periodic_end: bool) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks: list[float], samples: list[list[float]]) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks: list[float], samples: list[numpy.ndarray[numpy.float64[m, n]]]) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times: list[float], samples: list[list[float]]) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times, samples) -> Any: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times: list[float], samples: list[numpy.ndarray[numpy.float64[m, n]]]) -> PiecewisePolynomial: ...
    def RemoveFinalSegment(self) -> None: ...
    def Reshape(self, rows: int, cols: int) -> None: ...
    def ReverseTime(self) -> None: ...
    def ScaleTime(self, scale: float) -> None: ...
    def Transpose(self) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks: list[float], samples: list[list[float]]) -> PiecewisePolynomial: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks: list[float], samples: list[numpy.ndarray[numpy.float64[m, n]]]) -> PiecewisePolynomial: ...
    def derivative(self, derivative_order: int = ...) -> PiecewisePolynomial: ...
    def getPolynomial(self, segment_index: int, row: int = ..., col: int = ...) -> pydrake.polynomial.Polynomial: ...
    def getPolynomialMatrix(self, segment_index: int) -> numpy.ndarray[object[m, n]]: ...
    def getSegmentPolynomialDegree(self, segment_index: int, row: int = ..., col: int = ...) -> int: ...
    def isApprox(self, other: PiecewisePolynomial, tol: float, tol_type: pydrake.common.ToleranceType = ...) -> bool: ...
    def setPolynomialMatrixBlock(self, replacement: numpy.ndarray[object[m, n]], segment_index: int, row_start: int = ..., col_start: int = ...) -> None: ...
    def shiftRight(self, offset: float) -> None: ...
    def slice(self, start_segment_index: int, num_segments: int) -> PiecewisePolynomial: ...
    def __add__(self, arg0: PiecewisePolynomial) -> PiecewisePolynomial: ...
    def __copy__(self) -> PiecewisePolynomial: ...
    def __deepcopy__(self, arg0: dict) -> PiecewisePolynomial: ...
    def __getattr__(self, arg0: str) -> object: ...
    def __setattr__(self, arg0: str, arg1: object) -> None: ...

class PiecewisePolynomial_𝓣AutoDiffXd𝓤(PiecewiseTrajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def __init__(self, arg0: list[numpy.ndarray[object[m, n]]], arg1: list[pydrake.autodiffutils.AutoDiffXd]) -> None: ...
    @overload
    def __init__(self, arg0: list[pydrake.polynomial.Polynomial_TAutoDiffXdU], arg1: list[pydrake.autodiffutils.AutoDiffXd]) -> None: ...
    def AppendCubicHermiteSegment(self, time: pydrake.autodiffutils.AutoDiffXd, sample: numpy.ndarray[object[m, n], flags.f_contiguous], sample_dot: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def AppendFirstOrderSegment(self, time: pydrake.autodiffutils.AutoDiffXd, sample: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def Block(self, start_row: int, start_col: int, block_rows: int, block_cols: int) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def ConcatenateInTime(self, other: PiecewisePolynomial_TAutoDiffXdU) -> None: ...
    @overload
    @staticmethod
    def CubicHermite(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]], samples_dot: list[list[pydrake.autodiffutils.AutoDiffXd]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicHermite(breaks, samples, samples_dot) -> Any: ...
    @overload
    @staticmethod
    def CubicHermite(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]], samples_dot: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicShapePreserving(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]], zero_end_point_derivatives: bool = ...) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicShapePreserving(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]], zero_end_point_derivatives: bool = ...) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]], sample_dot_at_start: numpy.ndarray[object[m, n]], sample_dot_at_end: numpy.ndarray[object[m, n]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives() -> Any: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]], sample_dot_at_start: numpy.ndarray[object[m, n]], sample_dot_at_end: numpy.ndarray[object[m, n]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]], periodic_end_condition: bool = ...) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]], periodic_end: bool) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times, samples) -> Any: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def RemoveFinalSegment(self) -> None: ...
    def Reshape(self, rows: int, cols: int) -> None: ...
    def ReverseTime(self) -> None: ...
    def ScaleTime(self, scale: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    def Transpose(self) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def derivative(self, derivative_order: int = ...) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def getPolynomial(self, segment_index: int, row: int = ..., col: int = ...) -> pydrake.polynomial.Polynomial_TAutoDiffXdU: ...
    def getPolynomialMatrix(self, segment_index: int) -> numpy.ndarray[object[m, n]]: ...
    def getSegmentPolynomialDegree(self, segment_index: int, row: int = ..., col: int = ...) -> int: ...
    def isApprox(self, other: PiecewisePolynomial_TAutoDiffXdU, tol: float, tol_type: pydrake.common.ToleranceType = ...) -> bool: ...
    def setPolynomialMatrixBlock(self, replacement: numpy.ndarray[object[m, n]], segment_index: int, row_start: int = ..., col_start: int = ...) -> None: ...
    def shiftRight(self, offset: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    def slice(self, start_segment_index: int, num_segments: int) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def __add__(self, arg0: PiecewisePolynomial_TAutoDiffXdU) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def __copy__(self) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewisePolynomial_TAutoDiffXdU: ...

class PiecewisePolynomial_𝓣Expression𝓤(PiecewiseTrajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def __init__(self, arg0: list[numpy.ndarray[object[m, n]]], arg1: list[pydrake.symbolic.Expression]) -> None: ...
    @overload
    def __init__(self, arg0: list[pydrake.polynomial.Polynomial_TExpressionU], arg1: list[pydrake.symbolic.Expression]) -> None: ...
    def AppendCubicHermiteSegment(self, time: pydrake.symbolic.Expression, sample: numpy.ndarray[object[m, n], flags.f_contiguous], sample_dot: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def AppendFirstOrderSegment(self, time: pydrake.symbolic.Expression, sample: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def Block(self, start_row: int, start_col: int, block_rows: int, block_cols: int) -> PiecewisePolynomial_TExpressionU: ...
    def ConcatenateInTime(self, other: PiecewisePolynomial_TExpressionU) -> None: ...
    @overload
    @staticmethod
    def CubicHermite(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]], samples_dot: list[list[pydrake.symbolic.Expression]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicHermite(breaks, samples, samples_dot) -> Any: ...
    @overload
    @staticmethod
    def CubicHermite(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]], samples_dot: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicShapePreserving(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]], zero_end_point_derivatives: bool = ...) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicShapePreserving(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]], zero_end_point_derivatives: bool = ...) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]], sample_dot_at_start: numpy.ndarray[object[m, n]], sample_dot_at_end: numpy.ndarray[object[m, n]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives() -> Any: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]], sample_dot_at_start: numpy.ndarray[object[m, n]], sample_dot_at_end: numpy.ndarray[object[m, n]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]], periodic_end_condition: bool = ...) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]], periodic_end: bool) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times, samples) -> Any: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TExpressionU: ...
    def RemoveFinalSegment(self) -> None: ...
    def Reshape(self, rows: int, cols: int) -> None: ...
    def ReverseTime(self) -> None: ...
    def ScaleTime(self, scale: pydrake.symbolic.Expression) -> None: ...
    def Transpose(self) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TExpressionU: ...
    def derivative(self, derivative_order: int = ...) -> PiecewisePolynomial_TExpressionU: ...
    def getPolynomial(self, segment_index: int, row: int = ..., col: int = ...) -> pydrake.polynomial.Polynomial_TExpressionU: ...
    def getPolynomialMatrix(self, segment_index: int) -> numpy.ndarray[object[m, n]]: ...
    def getSegmentPolynomialDegree(self, segment_index: int, row: int = ..., col: int = ...) -> int: ...
    def isApprox(self, other: PiecewisePolynomial_TExpressionU, tol: float, tol_type: pydrake.common.ToleranceType = ...) -> bool: ...
    def setPolynomialMatrixBlock(self, replacement: numpy.ndarray[object[m, n]], segment_index: int, row_start: int = ..., col_start: int = ...) -> None: ...
    def shiftRight(self, offset: pydrake.symbolic.Expression) -> None: ...
    def slice(self, start_segment_index: int, num_segments: int) -> PiecewisePolynomial_TExpressionU: ...
    def __add__(self, arg0: PiecewisePolynomial_TExpressionU) -> PiecewisePolynomial_TExpressionU: ...
    def __copy__(self) -> PiecewisePolynomial_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewisePolynomial_TExpressionU: ...

class PiecewisePose(PiecewiseTrajectory):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, position_trajectory: PiecewisePolynomial, orientation_trajectory: PiecewiseQuaternionSlerp) -> None: ...
    def GetAcceleration(self, time: float) -> numpy.ndarray[numpy.float64[6, 1]]: ...
    def GetPose(self, time: float) -> pydrake.math.RigidTransform: ...
    def GetVelocity(self, time: float) -> numpy.ndarray[numpy.float64[6, 1]]: ...
    def IsApprox(self, other: PiecewisePose, tol: float) -> bool: ...
    @staticmethod
    def MakeCubicLinearWithEndLinearVelocity(times: list[float], poses: list[pydrake.math.RigidTransform], start_vel: numpy.ndarray[numpy.float64[3, 1]] = ..., end_vel: numpy.ndarray[numpy.float64[3, 1]] = ...) -> PiecewisePose: ...
    @staticmethod
    def MakeLinear(times: list[float], poses: list[pydrake.math.RigidTransform]) -> PiecewisePose: ...
    def get_orientation_trajectory(self) -> PiecewiseQuaternionSlerp: ...
    def get_position_trajectory(self) -> PiecewisePolynomial: ...
    def __copy__(self) -> PiecewisePose: ...
    def __deepcopy__(self, arg0: dict) -> PiecewisePose: ...

class PiecewisePose_𝓣AutoDiffXd𝓤(PiecewiseTrajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, position_trajectory: PiecewisePolynomial_TAutoDiffXdU, orientation_trajectory: PiecewiseQuaternionSlerp_TAutoDiffXdU) -> None: ...
    def GetAcceleration(self, time: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[6, 1]]: ...
    def GetPose(self, time: pydrake.autodiffutils.AutoDiffXd) -> pydrake.math.RigidTransform_TAutoDiffXdU: ...
    def GetVelocity(self, time: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[6, 1]]: ...
    def IsApprox(self, other: PiecewisePose_TAutoDiffXdU, tol: float) -> bool: ...
    @staticmethod
    def MakeCubicLinearWithEndLinearVelocity(times: list[pydrake.autodiffutils.AutoDiffXd], poses: list[pydrake.math.RigidTransform_TAutoDiffXdU], start_vel: numpy.ndarray[object[3, 1]] = ..., end_vel: numpy.ndarray[object[3, 1]] = ...) -> PiecewisePose_TAutoDiffXdU: ...
    @staticmethod
    def MakeLinear(times: list[pydrake.autodiffutils.AutoDiffXd], poses: list[pydrake.math.RigidTransform_TAutoDiffXdU]) -> PiecewisePose_TAutoDiffXdU: ...
    def get_orientation_trajectory(self) -> PiecewiseQuaternionSlerp_TAutoDiffXdU: ...
    def get_position_trajectory(self) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def __copy__(self) -> PiecewisePose_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewisePose_TAutoDiffXdU: ...

class PiecewisePose_𝓣Expression𝓤(PiecewiseTrajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, position_trajectory: PiecewisePolynomial_TExpressionU, orientation_trajectory: PiecewiseQuaternionSlerp_TExpressionU) -> None: ...
    def GetAcceleration(self, time: pydrake.symbolic.Expression) -> numpy.ndarray[object[6, 1]]: ...
    def GetPose(self, time: pydrake.symbolic.Expression) -> pydrake.math.RigidTransform_TExpressionU: ...
    def GetVelocity(self, time: pydrake.symbolic.Expression) -> numpy.ndarray[object[6, 1]]: ...
    def IsApprox(self, other: PiecewisePose_TExpressionU, tol: float) -> bool: ...
    @staticmethod
    def MakeCubicLinearWithEndLinearVelocity(times: list[pydrake.symbolic.Expression], poses: list[pydrake.math.RigidTransform_TExpressionU], start_vel: numpy.ndarray[object[3, 1]] = ..., end_vel: numpy.ndarray[object[3, 1]] = ...) -> PiecewisePose_TExpressionU: ...
    @staticmethod
    def MakeLinear(times: list[pydrake.symbolic.Expression], poses: list[pydrake.math.RigidTransform_TExpressionU]) -> PiecewisePose_TExpressionU: ...
    def get_orientation_trajectory(self) -> PiecewiseQuaternionSlerp_TExpressionU: ...
    def get_position_trajectory(self) -> PiecewisePolynomial_TExpressionU: ...
    def __copy__(self) -> PiecewisePose_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewisePose_TExpressionU: ...

class PiecewiseQuaternionSlerp(PiecewiseTrajectory):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, breaks: list[float], quaternions: list[pydrake.common.eigen_geometry.Quaternion]) -> None: ...
    @overload
    def __init__(self, breaks: list[float], rotation_matrices: list[numpy.ndarray[numpy.float64[3, 3]]]) -> None: ...
    @overload
    def __init__(self, breaks: list[float], rotation_matrices: list[pydrake.math.RotationMatrix]) -> None: ...
    @overload
    def __init__(self, breaks: list[float], angle_axes: list[pydrake.common.eigen_geometry.AngleAxis]) -> None: ...
    @overload
    def Append(self, time: float, quaternion: pydrake.common.eigen_geometry.Quaternion) -> None: ...
    @overload
    def Append(self, time: float, rotation_matrix: pydrake.math.RotationMatrix) -> None: ...
    @overload
    def Append(self, time: float, angle_axis: pydrake.common.eigen_geometry.AngleAxis) -> None: ...
    def angular_acceleration(self, time: float) -> numpy.ndarray[numpy.float64[3, 1]]: ...
    def angular_velocity(self, time: float) -> numpy.ndarray[numpy.float64[3, 1]]: ...
    def get_quaternion_samples(self) -> list[pydrake.common.eigen_geometry.Quaternion]: ...
    def orientation(self, time: float) -> pydrake.common.eigen_geometry.Quaternion: ...
    def __copy__(self) -> PiecewiseQuaternionSlerp: ...
    def __deepcopy__(self, arg0: dict) -> PiecewiseQuaternionSlerp: ...

class PiecewiseQuaternionSlerp_𝓣AutoDiffXd𝓤(PiecewiseTrajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.autodiffutils.AutoDiffXd], quaternions: list[pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.autodiffutils.AutoDiffXd], rotation_matrices: list[numpy.ndarray[object[3, 3]]]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.autodiffutils.AutoDiffXd], rotation_matrices: list[pydrake.math.RotationMatrix_TAutoDiffXdU]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.autodiffutils.AutoDiffXd], angle_axes: list[pydrake.common.eigen_geometry.AngleAxis_TAutoDiffXdU]) -> None: ...
    @overload
    def Append(self, time: pydrake.autodiffutils.AutoDiffXd, quaternion: pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU) -> None: ...
    @overload
    def Append(self, time: pydrake.autodiffutils.AutoDiffXd, rotation_matrix: pydrake.math.RotationMatrix_TAutoDiffXdU) -> None: ...
    @overload
    def Append(self, time: pydrake.autodiffutils.AutoDiffXd, angle_axis: pydrake.common.eigen_geometry.AngleAxis_TAutoDiffXdU) -> None: ...
    def angular_acceleration(self, time: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[3, 1]]: ...
    def angular_velocity(self, time: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[3, 1]]: ...
    def get_quaternion_samples(self) -> list[pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU]: ...
    def orientation(self, time: pydrake.autodiffutils.AutoDiffXd) -> pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU: ...
    def __copy__(self) -> PiecewiseQuaternionSlerp_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewiseQuaternionSlerp_TAutoDiffXdU: ...

class PiecewiseQuaternionSlerp_𝓣Expression𝓤(PiecewiseTrajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.symbolic.Expression], quaternions: list[pydrake.common.eigen_geometry.Quaternion_TExpressionU]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.symbolic.Expression], rotation_matrices: list[numpy.ndarray[object[3, 3]]]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.symbolic.Expression], rotation_matrices: list[pydrake.math.RotationMatrix_TExpressionU]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.symbolic.Expression], angle_axes: list[pydrake.common.eigen_geometry.AngleAxis_TExpressionU]) -> None: ...
    @overload
    def Append(self, time: pydrake.symbolic.Expression, quaternion: pydrake.common.eigen_geometry.Quaternion_TExpressionU) -> None: ...
    @overload
    def Append(self, time: pydrake.symbolic.Expression, rotation_matrix: pydrake.math.RotationMatrix_TExpressionU) -> None: ...
    @overload
    def Append(self, time: pydrake.symbolic.Expression, angle_axis: pydrake.common.eigen_geometry.AngleAxis_TExpressionU) -> None: ...
    def angular_acceleration(self, time: pydrake.symbolic.Expression) -> numpy.ndarray[object[3, 1]]: ...
    def angular_velocity(self, time: pydrake.symbolic.Expression) -> numpy.ndarray[object[3, 1]]: ...
    def get_quaternion_samples(self) -> list[pydrake.common.eigen_geometry.Quaternion_TExpressionU]: ...
    def orientation(self, time: pydrake.symbolic.Expression) -> pydrake.common.eigen_geometry.Quaternion_TExpressionU: ...
    def __copy__(self) -> PiecewiseQuaternionSlerp_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewiseQuaternionSlerp_TExpressionU: ...

class PiecewiseTrajectory(Trajectory):
    def __init__(self, *args, **kwargs) -> None: ...
    def duration(self, segment_index: int) -> float: ...
    @overload
    def end_time(self, segment_index: int) -> float: ...
    @overload
    def end_time(self) -> float: ...
    def get_number_of_segments(self) -> int: ...
    def get_segment_index(self, t: float) -> int: ...
    def get_segment_times(self) -> list[float]: ...
    def is_time_in_range(self, t: float) -> bool: ...
    @overload
    def start_time(self, segment_index: int) -> float: ...
    @overload
    def start_time(self) -> float: ...

class PiecewiseTrajectory_𝓣AutoDiffXd𝓤(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def duration(self, segment_index: int) -> pydrake.autodiffutils.AutoDiffXd: ...
    @overload
    def end_time(self, segment_index: int) -> pydrake.autodiffutils.AutoDiffXd: ...
    @overload
    def end_time(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def get_number_of_segments(self) -> int: ...
    def get_segment_index(self, t: pydrake.autodiffutils.AutoDiffXd) -> int: ...
    def get_segment_times(self) -> list[pydrake.autodiffutils.AutoDiffXd]: ...
    def is_time_in_range(self, t: pydrake.autodiffutils.AutoDiffXd) -> bool: ...
    @overload
    def start_time(self, segment_index: int) -> pydrake.autodiffutils.AutoDiffXd: ...
    @overload
    def start_time(self) -> pydrake.autodiffutils.AutoDiffXd: ...

class PiecewiseTrajectory_𝓣Expression𝓤(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def duration(self, segment_index: int) -> pydrake.symbolic.Expression: ...
    @overload
    def end_time(self, segment_index: int) -> pydrake.symbolic.Expression: ...
    @overload
    def end_time(self) -> pydrake.symbolic.Expression: ...
    def get_number_of_segments(self) -> int: ...
    def get_segment_index(self, t: pydrake.symbolic.Expression) -> int: ...
    def get_segment_times(self) -> list[pydrake.symbolic.Expression]: ...
    def is_time_in_range(self, t: pydrake.symbolic.Expression) -> pydrake.symbolic.Formula: ...
    @overload
    def start_time(self, segment_index: int) -> pydrake.symbolic.Expression: ...
    @overload
    def start_time(self) -> pydrake.symbolic.Expression: ...

class StackedTrajectory(Trajectory):
    def __init__(self, rowwise: bool = ...) -> None: ...
    def Append(self, arg0: Trajectory) -> None: ...
    def children(self) -> list[Trajectory]: ...
    def rowwise(self) -> bool: ...
    def __copy__(self) -> StackedTrajectory: ...
    def __deepcopy__(self, arg0: dict) -> StackedTrajectory: ...

class StackedTrajectory_𝓣AutoDiffXd𝓤(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, rowwise: bool = ...) -> None: ...
    def Append(self, arg0: Trajectory_TAutoDiffXdU) -> None: ...
    def children(self) -> list[Trajectory_TAutoDiffXdU]: ...
    def rowwise(self) -> bool: ...
    def __copy__(self) -> StackedTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> StackedTrajectory_TAutoDiffXdU: ...

class StackedTrajectory_𝓣Expression𝓤(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, rowwise: bool = ...) -> None: ...
    def Append(self, arg0: Trajectory_TExpressionU) -> None: ...
    def children(self) -> list[Trajectory_TExpressionU]: ...
    def rowwise(self) -> bool: ...
    def __copy__(self) -> StackedTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> StackedTrajectory_TExpressionU: ...

class Trajectory:
    def __init__(self) -> None: ...
    def Clone(self) -> Trajectory: ...
    def EvalDerivative(self, t: float, derivative_order: int = ...) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def MakeDerivative(self, derivative_order: int = ...) -> Trajectory: ...
    def cols(self) -> int: ...
    def end_time(self) -> float: ...
    def has_derivative(self) -> bool: ...
    def rows(self) -> int: ...
    def start_time(self) -> float: ...
    def value(self, t: float) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def vector_values(self, t: list[float]) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def __copy__(self) -> Trajectory: ...
    def __deepcopy__(self, arg0: dict) -> Trajectory: ...

class Trajectory_𝓣AutoDiffXd𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def Clone(self) -> Trajectory_TAutoDiffXdU: ...
    def EvalDerivative(self, t: pydrake.autodiffutils.AutoDiffXd, derivative_order: int = ...) -> numpy.ndarray[object[m, n]]: ...
    def MakeDerivative(self, derivative_order: int = ...) -> Trajectory_TAutoDiffXdU: ...
    def cols(self) -> int: ...
    def end_time(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def has_derivative(self) -> bool: ...
    def rows(self) -> int: ...
    def start_time(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def value(self, t: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def vector_values(self, t: list[pydrake.autodiffutils.AutoDiffXd]) -> numpy.ndarray[object[m, n]]: ...
    def __copy__(self) -> Trajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> Trajectory_TAutoDiffXdU: ...

class Trajectory_𝓣Expression𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def Clone(self) -> Trajectory_TExpressionU: ...
    def EvalDerivative(self, t: pydrake.symbolic.Expression, derivative_order: int = ...) -> numpy.ndarray[object[m, n]]: ...
    def MakeDerivative(self, derivative_order: int = ...) -> Trajectory_TExpressionU: ...
    def cols(self) -> int: ...
    def end_time(self) -> pydrake.symbolic.Expression: ...
    def has_derivative(self) -> bool: ...
    def rows(self) -> int: ...
    def start_time(self) -> pydrake.symbolic.Expression: ...
    def value(self, t: pydrake.symbolic.Expression) -> numpy.ndarray[object[m, n]]: ...
    def vector_values(self, t: list[pydrake.symbolic.Expression]) -> numpy.ndarray[object[m, n]]: ...
    def __copy__(self) -> Trajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> Trajectory_TExpressionU: ...

class _TemporaryName_N5drake12trajectories10TrajectoryINS_2ad8AutoDiffEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def Clone(self) -> Trajectory_TAutoDiffXdU: ...
    def EvalDerivative(self, t: pydrake.autodiffutils.AutoDiffXd, derivative_order: int = ...) -> numpy.ndarray[object[m, n]]: ...
    def MakeDerivative(self, derivative_order: int = ...) -> Trajectory_TAutoDiffXdU: ...
    def cols(self) -> int: ...
    def end_time(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def has_derivative(self) -> bool: ...
    def rows(self) -> int: ...
    def start_time(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def value(self, t: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def vector_values(self, t: list[pydrake.autodiffutils.AutoDiffXd]) -> numpy.ndarray[object[m, n]]: ...
    def __copy__(self) -> Trajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> Trajectory_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories10TrajectoryINS_8symbolic10ExpressionEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def Clone(self) -> Trajectory_TExpressionU: ...
    def EvalDerivative(self, t: pydrake.symbolic.Expression, derivative_order: int = ...) -> numpy.ndarray[object[m, n]]: ...
    def MakeDerivative(self, derivative_order: int = ...) -> Trajectory_TExpressionU: ...
    def cols(self) -> int: ...
    def end_time(self) -> pydrake.symbolic.Expression: ...
    def has_derivative(self) -> bool: ...
    def rows(self) -> int: ...
    def start_time(self) -> pydrake.symbolic.Expression: ...
    def value(self, t: pydrake.symbolic.Expression) -> numpy.ndarray[object[m, n]]: ...
    def vector_values(self, t: list[pydrake.symbolic.Expression]) -> numpy.ndarray[object[m, n]]: ...
    def __copy__(self) -> Trajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> Trajectory_TExpressionU: ...

class _TemporaryName_N5drake12trajectories11BezierCurveINS_2ad8AutoDiffEEE(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, start_time: float, end_time: float, control_points: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def BernsteinBasis(self, i: int, time: pydrake.autodiffutils.AutoDiffXd, order: int | None = ...) -> pydrake.autodiffutils.AutoDiffXd: ...
    def ElevateOrder(self) -> None: ...
    def GetExpression(self, time: pydrake.symbolic.Variable = ...) -> numpy.ndarray[object[m, 1]]: ...
    def control_points(self) -> numpy.ndarray[object[m, n]]: ...
    def order(self) -> int: ...
    def __copy__(self) -> BezierCurve_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> BezierCurve_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories11BezierCurveINS_8symbolic10ExpressionEEE(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, start_time: float, end_time: float, control_points: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def BernsteinBasis(self, i: int, time: pydrake.symbolic.Expression, order: int | None = ...) -> pydrake.symbolic.Expression: ...
    def ElevateOrder(self) -> None: ...
    def GetExpression(self, time: pydrake.symbolic.Variable = ...) -> numpy.ndarray[object[m, 1]]: ...
    def control_points(self) -> numpy.ndarray[object[m, n]]: ...
    def order(self) -> int: ...
    def __copy__(self) -> BezierCurve_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> BezierCurve_TExpressionU: ...

class _TemporaryName_N5drake12trajectories13PiecewisePoseINS_2ad8AutoDiffEEE(PiecewiseTrajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, position_trajectory: PiecewisePolynomial_TAutoDiffXdU, orientation_trajectory: PiecewiseQuaternionSlerp_TAutoDiffXdU) -> None: ...
    def GetAcceleration(self, time: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[6, 1]]: ...
    def GetPose(self, time: pydrake.autodiffutils.AutoDiffXd) -> pydrake.math.RigidTransform_TAutoDiffXdU: ...
    def GetVelocity(self, time: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[6, 1]]: ...
    def IsApprox(self, other: PiecewisePose_TAutoDiffXdU, tol: float) -> bool: ...
    @staticmethod
    def MakeCubicLinearWithEndLinearVelocity(times: list[pydrake.autodiffutils.AutoDiffXd], poses: list[pydrake.math.RigidTransform_TAutoDiffXdU], start_vel: numpy.ndarray[object[3, 1]] = ..., end_vel: numpy.ndarray[object[3, 1]] = ...) -> PiecewisePose_TAutoDiffXdU: ...
    @staticmethod
    def MakeLinear(times: list[pydrake.autodiffutils.AutoDiffXd], poses: list[pydrake.math.RigidTransform_TAutoDiffXdU]) -> PiecewisePose_TAutoDiffXdU: ...
    def get_orientation_trajectory(self) -> PiecewiseQuaternionSlerp_TAutoDiffXdU: ...
    def get_position_trajectory(self) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def __copy__(self) -> PiecewisePose_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewisePose_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories13PiecewisePoseINS_8symbolic10ExpressionEEE(PiecewiseTrajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, position_trajectory: PiecewisePolynomial_TExpressionU, orientation_trajectory: PiecewiseQuaternionSlerp_TExpressionU) -> None: ...
    def GetAcceleration(self, time: pydrake.symbolic.Expression) -> numpy.ndarray[object[6, 1]]: ...
    def GetPose(self, time: pydrake.symbolic.Expression) -> pydrake.math.RigidTransform_TExpressionU: ...
    def GetVelocity(self, time: pydrake.symbolic.Expression) -> numpy.ndarray[object[6, 1]]: ...
    def IsApprox(self, other: PiecewisePose_TExpressionU, tol: float) -> bool: ...
    @staticmethod
    def MakeCubicLinearWithEndLinearVelocity(times: list[pydrake.symbolic.Expression], poses: list[pydrake.math.RigidTransform_TExpressionU], start_vel: numpy.ndarray[object[3, 1]] = ..., end_vel: numpy.ndarray[object[3, 1]] = ...) -> PiecewisePose_TExpressionU: ...
    @staticmethod
    def MakeLinear(times: list[pydrake.symbolic.Expression], poses: list[pydrake.math.RigidTransform_TExpressionU]) -> PiecewisePose_TExpressionU: ...
    def get_orientation_trajectory(self) -> PiecewiseQuaternionSlerp_TExpressionU: ...
    def get_position_trajectory(self) -> PiecewisePolynomial_TExpressionU: ...
    def __copy__(self) -> PiecewisePose_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewisePose_TExpressionU: ...

class _TemporaryName_N5drake12trajectories17BsplineTrajectoryINS_2ad8AutoDiffEEE(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, basis: pydrake.math.BsplineBasis_TAutoDiffXdU, control_points: list[list[pydrake.autodiffutils.AutoDiffXd]]) -> None: ...
    @overload
    def __init__(self, basis: pydrake.math.BsplineBasis_TAutoDiffXdU, control_points: list[numpy.ndarray[object[m, n]]]) -> None: ...
    def CopyBlock(self, start_row: int, start_col: int, block_rows: int, block_cols: int) -> BsplineTrajectory_TAutoDiffXdU: ...
    def CopyHead(self, n: int) -> BsplineTrajectory_TAutoDiffXdU: ...
    def EvaluateLinearInControlPoints(self, parameter_value: pydrake.autodiffutils.AutoDiffXd, derivative_order: int = ...) -> numpy.ndarray[object[m, 1]]: ...
    def FinalValue(self) -> numpy.ndarray[object[m, n]]: ...
    def InitialValue(self) -> numpy.ndarray[object[m, n]]: ...
    def InsertKnots(self, additional_knots: list[pydrake.autodiffutils.AutoDiffXd]) -> None: ...
    def basis(self) -> pydrake.math.BsplineBasis_TAutoDiffXdU: ...
    def control_points(self) -> list[numpy.ndarray[object[m, n]]]: ...
    def num_control_points(self) -> int: ...
    def __copy__(self) -> BsplineTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> BsplineTrajectory_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories17BsplineTrajectoryINS_8symbolic10ExpressionEEE(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, basis: pydrake.math.BsplineBasis_TExpressionU, control_points: list[list[pydrake.symbolic.Expression]]) -> None: ...
    @overload
    def __init__(self, basis: pydrake.math.BsplineBasis_TExpressionU, control_points: list[numpy.ndarray[object[m, n]]]) -> None: ...
    def CopyBlock(self, start_row: int, start_col: int, block_rows: int, block_cols: int) -> BsplineTrajectory_TExpressionU: ...
    def CopyHead(self, n: int) -> BsplineTrajectory_TExpressionU: ...
    def EvaluateLinearInControlPoints(self, parameter_value: pydrake.symbolic.Expression, derivative_order: int = ...) -> numpy.ndarray[object[m, 1]]: ...
    def FinalValue(self) -> numpy.ndarray[object[m, n]]: ...
    def InitialValue(self) -> numpy.ndarray[object[m, n]]: ...
    def InsertKnots(self, additional_knots: list[pydrake.symbolic.Expression]) -> None: ...
    def basis(self) -> pydrake.math.BsplineBasis_TExpressionU: ...
    def control_points(self) -> list[numpy.ndarray[object[m, n]]]: ...
    def num_control_points(self) -> int: ...
    def __copy__(self) -> BsplineTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> BsplineTrajectory_TExpressionU: ...

class _TemporaryName_N5drake12trajectories17StackedTrajectoryINS_2ad8AutoDiffEEE(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, rowwise: bool = ...) -> None: ...
    def Append(self, arg0: Trajectory_TAutoDiffXdU) -> None: ...
    def children(self) -> list[Trajectory_TAutoDiffXdU]: ...
    def rowwise(self) -> bool: ...
    def __copy__(self) -> StackedTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> StackedTrajectory_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories17StackedTrajectoryINS_8symbolic10ExpressionEEE(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, rowwise: bool = ...) -> None: ...
    def Append(self, arg0: Trajectory_TExpressionU) -> None: ...
    def children(self) -> list[Trajectory_TExpressionU]: ...
    def rowwise(self) -> bool: ...
    def __copy__(self) -> StackedTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> StackedTrajectory_TExpressionU: ...

class _TemporaryName_N5drake12trajectories19CompositeTrajectoryINS_2ad8AutoDiffEEE(PiecewiseTrajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, segments: list[Trajectory_TAutoDiffXdU]) -> None: ...
    @staticmethod
    def AlignAndConcatenate(segments: list[Trajectory_TAutoDiffXdU]) -> CompositeTrajectory_TAutoDiffXdU: ...
    def segment(self, segment_index: int) -> Trajectory_TAutoDiffXdU: ...
    def __copy__(self) -> CompositeTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> CompositeTrajectory_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories19CompositeTrajectoryINS_8symbolic10ExpressionEEE(PiecewiseTrajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, segments: list[Trajectory_TExpressionU]) -> None: ...
    @staticmethod
    def AlignAndConcatenate(segments: list[Trajectory_TExpressionU]) -> CompositeTrajectory_TExpressionU: ...
    def segment(self, segment_index: int) -> Trajectory_TExpressionU: ...
    def __copy__(self) -> CompositeTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> CompositeTrajectory_TExpressionU: ...

class _TemporaryName_N5drake12trajectories19PiecewisePolynomialINS_2ad8AutoDiffEEE(PiecewiseTrajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def __init__(self, arg0: list[numpy.ndarray[object[m, n]]], arg1: list[pydrake.autodiffutils.AutoDiffXd]) -> None: ...
    @overload
    def __init__(self, arg0: list[pydrake.polynomial.Polynomial_TAutoDiffXdU], arg1: list[pydrake.autodiffutils.AutoDiffXd]) -> None: ...
    def AppendCubicHermiteSegment(self, time: pydrake.autodiffutils.AutoDiffXd, sample: numpy.ndarray[object[m, n], flags.f_contiguous], sample_dot: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def AppendFirstOrderSegment(self, time: pydrake.autodiffutils.AutoDiffXd, sample: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def Block(self, start_row: int, start_col: int, block_rows: int, block_cols: int) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def ConcatenateInTime(self, other: PiecewisePolynomial_TAutoDiffXdU) -> None: ...
    @overload
    @staticmethod
    def CubicHermite(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]], samples_dot: list[list[pydrake.autodiffutils.AutoDiffXd]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicHermite(breaks, samples, samples_dot) -> Any: ...
    @overload
    @staticmethod
    def CubicHermite(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]], samples_dot: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicShapePreserving(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]], zero_end_point_derivatives: bool = ...) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicShapePreserving(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]], zero_end_point_derivatives: bool = ...) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]], sample_dot_at_start: numpy.ndarray[object[m, n]], sample_dot_at_end: numpy.ndarray[object[m, n]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives() -> Any: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]], sample_dot_at_start: numpy.ndarray[object[m, n]], sample_dot_at_end: numpy.ndarray[object[m, n]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]], periodic_end_condition: bool = ...) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]], periodic_end: bool) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times, samples) -> Any: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def RemoveFinalSegment(self) -> None: ...
    def Reshape(self, rows: int, cols: int) -> None: ...
    def ReverseTime(self) -> None: ...
    def ScaleTime(self, scale: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    def Transpose(self) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[list[pydrake.autodiffutils.AutoDiffXd]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks: list[pydrake.autodiffutils.AutoDiffXd], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def derivative(self, derivative_order: int = ...) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def getPolynomial(self, segment_index: int, row: int = ..., col: int = ...) -> pydrake.polynomial.Polynomial_TAutoDiffXdU: ...
    def getPolynomialMatrix(self, segment_index: int) -> numpy.ndarray[object[m, n]]: ...
    def getSegmentPolynomialDegree(self, segment_index: int, row: int = ..., col: int = ...) -> int: ...
    def isApprox(self, other: PiecewisePolynomial_TAutoDiffXdU, tol: float, tol_type: pydrake.common.ToleranceType = ...) -> bool: ...
    def setPolynomialMatrixBlock(self, replacement: numpy.ndarray[object[m, n]], segment_index: int, row_start: int = ..., col_start: int = ...) -> None: ...
    def shiftRight(self, offset: pydrake.autodiffutils.AutoDiffXd) -> None: ...
    def slice(self, start_segment_index: int, num_segments: int) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def __add__(self, arg0: PiecewisePolynomial_TAutoDiffXdU) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def __copy__(self) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewisePolynomial_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories19PiecewisePolynomialINS_8symbolic10ExpressionEEE(PiecewiseTrajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def __init__(self, arg0: list[numpy.ndarray[object[m, n]]], arg1: list[pydrake.symbolic.Expression]) -> None: ...
    @overload
    def __init__(self, arg0: list[pydrake.polynomial.Polynomial_TExpressionU], arg1: list[pydrake.symbolic.Expression]) -> None: ...
    def AppendCubicHermiteSegment(self, time: pydrake.symbolic.Expression, sample: numpy.ndarray[object[m, n], flags.f_contiguous], sample_dot: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def AppendFirstOrderSegment(self, time: pydrake.symbolic.Expression, sample: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def Block(self, start_row: int, start_col: int, block_rows: int, block_cols: int) -> PiecewisePolynomial_TExpressionU: ...
    def ConcatenateInTime(self, other: PiecewisePolynomial_TExpressionU) -> None: ...
    @overload
    @staticmethod
    def CubicHermite(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]], samples_dot: list[list[pydrake.symbolic.Expression]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicHermite(breaks, samples, samples_dot) -> Any: ...
    @overload
    @staticmethod
    def CubicHermite(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]], samples_dot: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicShapePreserving(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]], zero_end_point_derivatives: bool = ...) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicShapePreserving(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]], zero_end_point_derivatives: bool = ...) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]], sample_dot_at_start: numpy.ndarray[object[m, n]], sample_dot_at_end: numpy.ndarray[object[m, n]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives() -> Any: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]], sample_dot_at_start: numpy.ndarray[object[m, n]], sample_dot_at_end: numpy.ndarray[object[m, n]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]], periodic_end_condition: bool = ...) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def CubicWithContinuousSecondDerivatives(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]], periodic_end: bool) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def FirstOrderHold(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times, samples) -> Any: ...
    @overload
    @staticmethod
    def LagrangeInterpolatingPolynomial(times: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TExpressionU: ...
    def RemoveFinalSegment(self) -> None: ...
    def Reshape(self, rows: int, cols: int) -> None: ...
    def ReverseTime(self) -> None: ...
    def ScaleTime(self, scale: pydrake.symbolic.Expression) -> None: ...
    def Transpose(self) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks: list[pydrake.symbolic.Expression], samples: list[list[pydrake.symbolic.Expression]]) -> PiecewisePolynomial_TExpressionU: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks, samples) -> Any: ...
    @overload
    @staticmethod
    def ZeroOrderHold(breaks: list[pydrake.symbolic.Expression], samples: list[numpy.ndarray[object[m, n]]]) -> PiecewisePolynomial_TExpressionU: ...
    def derivative(self, derivative_order: int = ...) -> PiecewisePolynomial_TExpressionU: ...
    def getPolynomial(self, segment_index: int, row: int = ..., col: int = ...) -> pydrake.polynomial.Polynomial_TExpressionU: ...
    def getPolynomialMatrix(self, segment_index: int) -> numpy.ndarray[object[m, n]]: ...
    def getSegmentPolynomialDegree(self, segment_index: int, row: int = ..., col: int = ...) -> int: ...
    def isApprox(self, other: PiecewisePolynomial_TExpressionU, tol: float, tol_type: pydrake.common.ToleranceType = ...) -> bool: ...
    def setPolynomialMatrixBlock(self, replacement: numpy.ndarray[object[m, n]], segment_index: int, row_start: int = ..., col_start: int = ...) -> None: ...
    def shiftRight(self, offset: pydrake.symbolic.Expression) -> None: ...
    def slice(self, start_segment_index: int, num_segments: int) -> PiecewisePolynomial_TExpressionU: ...
    def __add__(self, arg0: PiecewisePolynomial_TExpressionU) -> PiecewisePolynomial_TExpressionU: ...
    def __copy__(self) -> PiecewisePolynomial_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewisePolynomial_TExpressionU: ...

class _TemporaryName_N5drake12trajectories19PiecewiseTrajectoryINS_2ad8AutoDiffEEE(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def duration(self, segment_index: int) -> pydrake.autodiffutils.AutoDiffXd: ...
    @overload
    def end_time(self, segment_index: int) -> pydrake.autodiffutils.AutoDiffXd: ...
    @overload
    def end_time(self) -> pydrake.autodiffutils.AutoDiffXd: ...
    def get_number_of_segments(self) -> int: ...
    def get_segment_index(self, t: pydrake.autodiffutils.AutoDiffXd) -> int: ...
    def get_segment_times(self) -> list[pydrake.autodiffutils.AutoDiffXd]: ...
    def is_time_in_range(self, t: pydrake.autodiffutils.AutoDiffXd) -> bool: ...
    @overload
    def start_time(self, segment_index: int) -> pydrake.autodiffutils.AutoDiffXd: ...
    @overload
    def start_time(self) -> pydrake.autodiffutils.AutoDiffXd: ...

class _TemporaryName_N5drake12trajectories19PiecewiseTrajectoryINS_8symbolic10ExpressionEEE(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def duration(self, segment_index: int) -> pydrake.symbolic.Expression: ...
    @overload
    def end_time(self, segment_index: int) -> pydrake.symbolic.Expression: ...
    @overload
    def end_time(self) -> pydrake.symbolic.Expression: ...
    def get_number_of_segments(self) -> int: ...
    def get_segment_index(self, t: pydrake.symbolic.Expression) -> int: ...
    def get_segment_times(self) -> list[pydrake.symbolic.Expression]: ...
    def is_time_in_range(self, t: pydrake.symbolic.Expression) -> pydrake.symbolic.Formula: ...
    @overload
    def start_time(self, segment_index: int) -> pydrake.symbolic.Expression: ...
    @overload
    def start_time(self) -> pydrake.symbolic.Expression: ...

class _TemporaryName_N5drake12trajectories20DerivativeTrajectoryINS_2ad8AutoDiffEEE(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, nominal: Trajectory_TAutoDiffXdU, derivative_order: int = ...) -> None: ...
    def __copy__(self) -> DerivativeTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> DerivativeTrajectory_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories20DerivativeTrajectoryINS_8symbolic10ExpressionEEE(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, nominal: Trajectory_TExpressionU, derivative_order: int = ...) -> None: ...
    def __copy__(self) -> DerivativeTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> DerivativeTrajectory_TExpressionU: ...

class _TemporaryName_N5drake12trajectories22DiscreteTimeTrajectoryINS_2ad8AutoDiffEEE(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, times: list[pydrake.autodiffutils.AutoDiffXd], values: list[numpy.ndarray[object[m, n]]], time_comparison_tolerance: float = ...) -> None: ...
    def ToZeroOrderHold(self) -> PiecewisePolynomial_TAutoDiffXdU: ...
    def get_times(self) -> list[pydrake.autodiffutils.AutoDiffXd]: ...
    def num_times(self) -> int: ...
    def time_comparison_tolerance(self) -> float: ...
    def __copy__(self) -> DiscreteTimeTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> DiscreteTimeTrajectory_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories22DiscreteTimeTrajectoryINS_8symbolic10ExpressionEEE(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, times: list[pydrake.symbolic.Expression], values: list[numpy.ndarray[object[m, n]]], time_comparison_tolerance: float = ...) -> None: ...
    def ToZeroOrderHold(self) -> PiecewisePolynomial_TExpressionU: ...
    def get_times(self) -> list[pydrake.symbolic.Expression]: ...
    def num_times(self) -> int: ...
    def time_comparison_tolerance(self) -> float: ...
    def __copy__(self) -> DiscreteTimeTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> DiscreteTimeTrajectory_TExpressionU: ...

class _TemporaryName_N5drake12trajectories24FunctionHandleTrajectoryINS_2ad8AutoDiffEEE(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, func: Callable[[pydrake.autodiffutils.AutoDiffXd], numpy.ndarray[object[m, n]]], rows: int, cols: int = ..., start_time: float = ..., end_time: float = ...) -> None: ...
    def set_derivative(self, func: Callable[[pydrake.autodiffutils.AutoDiffXd, int], numpy.ndarray[object[m, n]]]) -> None: ...
    def __copy__(self) -> FunctionHandleTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> FunctionHandleTrajectory_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories24FunctionHandleTrajectoryINS_8symbolic10ExpressionEEE(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, func: Callable[[pydrake.symbolic.Expression], numpy.ndarray[object[m, n]]], rows: int, cols: int = ..., start_time: float = ..., end_time: float = ...) -> None: ...
    def set_derivative(self, func: Callable[[pydrake.symbolic.Expression, int], numpy.ndarray[object[m, n]]]) -> None: ...
    def __copy__(self) -> FunctionHandleTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> FunctionHandleTrajectory_TExpressionU: ...

class _TemporaryName_N5drake12trajectories24PiecewiseQuaternionSlerpINS_2ad8AutoDiffEEE(PiecewiseTrajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.autodiffutils.AutoDiffXd], quaternions: list[pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.autodiffutils.AutoDiffXd], rotation_matrices: list[numpy.ndarray[object[3, 3]]]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.autodiffutils.AutoDiffXd], rotation_matrices: list[pydrake.math.RotationMatrix_TAutoDiffXdU]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.autodiffutils.AutoDiffXd], angle_axes: list[pydrake.common.eigen_geometry.AngleAxis_TAutoDiffXdU]) -> None: ...
    @overload
    def Append(self, time: pydrake.autodiffutils.AutoDiffXd, quaternion: pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU) -> None: ...
    @overload
    def Append(self, time: pydrake.autodiffutils.AutoDiffXd, rotation_matrix: pydrake.math.RotationMatrix_TAutoDiffXdU) -> None: ...
    @overload
    def Append(self, time: pydrake.autodiffutils.AutoDiffXd, angle_axis: pydrake.common.eigen_geometry.AngleAxis_TAutoDiffXdU) -> None: ...
    def angular_acceleration(self, time: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[3, 1]]: ...
    def angular_velocity(self, time: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[3, 1]]: ...
    def get_quaternion_samples(self) -> list[pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU]: ...
    def orientation(self, time: pydrake.autodiffutils.AutoDiffXd) -> pydrake.common.eigen_geometry.Quaternion_TAutoDiffXdU: ...
    def __copy__(self) -> PiecewiseQuaternionSlerp_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewiseQuaternionSlerp_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories24PiecewiseQuaternionSlerpINS_8symbolic10ExpressionEEE(PiecewiseTrajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.symbolic.Expression], quaternions: list[pydrake.common.eigen_geometry.Quaternion_TExpressionU]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.symbolic.Expression], rotation_matrices: list[numpy.ndarray[object[3, 3]]]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.symbolic.Expression], rotation_matrices: list[pydrake.math.RotationMatrix_TExpressionU]) -> None: ...
    @overload
    def __init__(self, breaks: list[pydrake.symbolic.Expression], angle_axes: list[pydrake.common.eigen_geometry.AngleAxis_TExpressionU]) -> None: ...
    @overload
    def Append(self, time: pydrake.symbolic.Expression, quaternion: pydrake.common.eigen_geometry.Quaternion_TExpressionU) -> None: ...
    @overload
    def Append(self, time: pydrake.symbolic.Expression, rotation_matrix: pydrake.math.RotationMatrix_TExpressionU) -> None: ...
    @overload
    def Append(self, time: pydrake.symbolic.Expression, angle_axis: pydrake.common.eigen_geometry.AngleAxis_TExpressionU) -> None: ...
    def angular_acceleration(self, time: pydrake.symbolic.Expression) -> numpy.ndarray[object[3, 1]]: ...
    def angular_velocity(self, time: pydrake.symbolic.Expression) -> numpy.ndarray[object[3, 1]]: ...
    def get_quaternion_samples(self) -> list[pydrake.common.eigen_geometry.Quaternion_TExpressionU]: ...
    def orientation(self, time: pydrake.symbolic.Expression) -> pydrake.common.eigen_geometry.Quaternion_TExpressionU: ...
    def __copy__(self) -> PiecewiseQuaternionSlerp_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> PiecewiseQuaternionSlerp_TExpressionU: ...

class _TemporaryName_N5drake12trajectories27PathParameterizedTrajectoryINS_2ad8AutoDiffEEE(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, path: Trajectory_TAutoDiffXdU, time_scaling: Trajectory_TAutoDiffXdU) -> None: ...
    def path(self) -> Trajectory_TAutoDiffXdU: ...
    def time_scaling(self) -> Trajectory_TAutoDiffXdU: ...
    def __copy__(self) -> PathParameterizedTrajectory_TAutoDiffXdU: ...
    def __deepcopy__(self, arg0: dict) -> PathParameterizedTrajectory_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories27PathParameterizedTrajectoryINS_8symbolic10ExpressionEEE(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, path: Trajectory_TExpressionU, time_scaling: Trajectory_TExpressionU) -> None: ...
    def path(self) -> Trajectory_TExpressionU: ...
    def time_scaling(self) -> Trajectory_TExpressionU: ...
    def __copy__(self) -> PathParameterizedTrajectory_TExpressionU: ...
    def __deepcopy__(self, arg0: dict) -> PathParameterizedTrajectory_TExpressionU: ...

class _TemporaryName_N5drake12trajectories8internal17WrappedTrajectoryINS_2ad8AutoDiffEEE(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, trajectory: Trajectory_TAutoDiffXdU) -> None: ...
    def unwrap(self) -> Trajectory_TAutoDiffXdU: ...

class _TemporaryName_N5drake12trajectories8internal17WrappedTrajectoryINS_8symbolic10ExpressionEEE(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, trajectory: Trajectory_TExpressionU) -> None: ...
    def unwrap(self) -> Trajectory_TExpressionU: ...

class _WrappedTrajectory(Trajectory):
    def __init__(self, trajectory: Trajectory) -> None: ...
    def unwrap(self) -> Trajectory: ...

class _WrappedTrajectory_𝓣AutoDiffXd𝓤(Trajectory_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, trajectory: Trajectory_TAutoDiffXdU) -> None: ...
    def unwrap(self) -> Trajectory_TAutoDiffXdU: ...

class _WrappedTrajectory_𝓣Expression𝓤(Trajectory_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, trajectory: Trajectory_TExpressionU) -> None: ...
    def unwrap(self) -> Trajectory_TExpressionU: ...



# See `ExecuteExtraPythonCode` in `pydrake_pybind.h` for usage details and
# rationale.

# ruff: noqa: F821 (undefined-name). This file is only a fragment.

import numpy as np


def InitializeAutoDiffTuple(*args):
    """Given a series of array_like input arguments, create a tuple of
    corresponding AutoDiff matrices with values equal to the input matrices
    and properly initialized derivative vectors.

    The size of the derivative vector of each element of the matrices in the
    output tuple will be the same, and will equal the sum of the number of
    elements of the matrices in args.

    The 0th element of the derivative vectors will correspond to the
    derivative with respect to the 0th element of the first argument.
    Subsequent derivative vector elements correspond first to subsequent
    elements of the first input argument (traversed first by row, then by
    column), and so on for subsequent arguments.

    This is a pythonic implementation of drake::math::InitializeAutoDiffTuple
    in C++.
    """

    num_derivatives = 0
    for arg in args:
        num_derivatives += np.asarray(arg).size

    autodiff_tuple = []
    deriv_num_start = 0
    for arg in args:
        autodiff_tuple.append(
            InitializeAutoDiff(arg, num_derivatives, deriv_num_start)
        )
        deriv_num_start += np.asarray(arg).size

    return tuple(autodiff_tuple)


@np.vectorize
def autodiff_equal_to(a, b, *, semantic=False):
    """
    Provides a structural equality check for arrays of AutoDiffXd scalars, i.e.
    returns True if both the values and derivates are equal.

    Arguments:
        a, b:
            Arrays to compare.
        semantic:
            If False, performs *literal* comparison, meaning the value and
            derivatives must match in both value and shape.
            If True, performs *semantic* comparison, meaning that empty
            derivatives is equivalent to purely zero-valued derivatives.
            Note: Zero-valued derivatives of different size are *not*
            equivalent.
    """
    assert isinstance(a, AutoDiffXd), type(a)
    assert isinstance(b, AutoDiffXd), type(b)
    if a.value() == b.value():
        da = a.derivatives()
        db = b.derivatives()
        if da.shape == db.shape and (da == db).all():
            return True
        da_empty = da.size == 0
        db_empty = db.size == 0
        if semantic and (da_empty or db_empty):
            da_zero = (da == 0.0).all()
            db_zero = (db == 0.0).all()
            if (da_zero and db_empty) or (da_empty and db_zero):
                return True
    return False



# ruff: noqa: F821 (undefined-name). This file is only a fragment.

import functools
import logging as _logging
import sys
import typing

import numpy as np

_root_logger = _logging.getLogger()
_drake_logger = _logging.getLogger("drake")


def _python_level_to_spdlog(level: int):
    """Returns the spdlog string level that enables C++ logging at the given
    Python logging level, for use with pydrake.common._set_log_level.
    """
    if level >= _logging.CRITICAL:
        return "critical"
    if level >= _logging.ERROR:
        return "err"
    if level >= _logging.WARNING:
        return "warn"
    if level >= _logging.INFO:
        return "info"
    if level >= _logging.DEBUG:
        return "debug"
    return "trace"


def _sync_spdlog_level():
    """Updates Drake's C++ spdlog level threshold to match the effective level
    of Drake's Python logger. This will either be the Drake Logger's level or
    else the root Logger's level in case Drake Logger's level is NOTSET.

    This only syncs the "effective" level, not the "enabled for" level. The
    "enabled for" level would also incorporate the global "logging.disable"
    setting, but we do not reflect that back into C++ spdlog at the moment.
    """
    if not _drake_logger._tied_to_spdlog:
        return
    level = _drake_logger.level or _root_logger.level
    _set_log_level(_python_level_to_spdlog(level))


def _monkey_patch_logger_level_events():
    """Adds a hook into Drake's Python Logger object such that changes to
    Python logging levels are reflected back into Drake's C++ spdlog level.
    """

    # To notice log level changes (whether to the root logger or our logger) we
    # intercept calls to our logger's cache-clearing function. Specifically,
    # when a user calls `Logger.setLevel(...)`, the logger tells the manager
    # singleton to clear its cache ...
    #
    # https://github.com/python/cpython/blob/c2b57974/Lib/logging/__init__.py#L1457-L1462
    #
    # ... which asks each Logger in turn to clear its cache.
    #
    # https://github.com/python/cpython/blob/c2b57974/Lib/logging/__init__.py#L1412-L1423
    #
    # That notification is triggered for any logger level change, including
    # both the root logger and Drake's own logger. Therefore, syncing the C++
    # level based on cache-clearing events is sufficient to cover all cases.
    #
    # This relies on the implementation details of CPython's logging module,
    # so we might need to adapt this technique to track CPython changes. Our
    # CI testing will inform us in case this technique ever stops working.
    class spdlog_syncing_dict(dict):
        def clear(self):
            super().clear()
            _sync_spdlog_level()

    _drake_logger._cache = spdlog_syncing_dict()


# Reflect the Python level to C++ level iff the Python sink is fed by spdlog.
if getattr(_drake_logger, "_tied_to_spdlog", False):
    _monkey_patch_logger_level_events()


def configure_logging():
    """Convenience function that configures the root Python logging module in
    a tasteful way for Drake. Using this function is totally optional; there
    is no requirement to call it prior to using Drake or generating messages.
    We offer it as a convenience only because Python's logging defaults are
    more spartan than Drake's C++ logging format (e.g., Python does not show
    message timestamps by default).

    Note:
        pydrake logs using Python's built-in ``logging`` module. To access
        pydrake's ``logging.Logger``, use ``logging.getLogger("drake")``.
        You can configure log settings using that object whether or not you
        have called ``configure_logging()`` first.

    See also:
        https://docs.python.org/3/library/logging.html
    """
    format = "[%(asctime)s] [%(name)s] [%(levelname)s] %(message)s"
    _logging.basicConfig(level=_logging.INFO, format=format)
    _drake_logger.setLevel(_logging.NOTSET)
    _logging.addLevelName(5, "TRACE")


def use_native_cpp_logging():
    """By default, pydrake's C++ code routes all of its log messages to
    Python's ``logging`` module; this function opts-out of that feature.

    After this function has been called, pydrake's C++ code will log directly
    to stderr, with no interaction with Python. (The Python settings for log
    level threshold and message formatting will no longer affect the C++ log
    messages.)

    This can be useful to avoid C++ logging touching the GIL, e.g., when using
    Python's ``threading`` module.

    This function is not thread-safe. No other threads should be running when
    it is called.

    See also the `environment variable
    <https://drake.mit.edu/doxygen_cxx/group__environment__variables.html>`_
    ``DRAKE_PYTHON_LOGGING``, which can also be used to opt-out.

    Raises:
        RuntimeError: If the reconfiguration is not possible, e.g., if you have
            already manually adjusted the C++ logging configuration.
    """
    _use_native_cpp_logging()
    _drake_logger._tied_to_spdlog = False


def _wrap_to_match_input_shape(f):
    # See docstring for `WrapToMatchInputShape` in `eigen_pybind.h` for more
    # details.
    # N.B. We cannot use `inspect.Signature` due to the fact that pybind11's
    # instance method is not inspectable for overloads.
    assert callable(f), f

    @functools.wraps(f)
    def wrapper(self, *args, **kwargs):
        # Call the function first to permit it to raise the appropriate
        # TypeError from pybind11 if the inputs are not correctly formatted.
        out = f(self, *args, **kwargs)
        if isinstance(out, np.ndarray):
            arg_list = tuple(args) + tuple(kwargs.values())
            assert len(arg_list) == 1
            (arg,) = arg_list
            in_shape = np.asarray(arg).shape
            return out.reshape(in_shape)
        else:
            return out

    return wrapper


class _MangledName:
    """Provides recipes for mangling and demangling names for templated code.

    For example, the template instantiation expression LeafSystem_[AutoDiffXd]
    refers to Python class named LeafSystem_𝓣AutoDiffXd𝓤. We refer to the
    former as the "pretty" name and the latter as the "mangled" name.

    We need to use name mangling because Python class and function names must
    be valid identifiers (i.e., alphanumeric characters, with underscores).
    The pretty name LeafSystem_[AutoDiffXd] is a valid *expression* but it is
    not a valid *identifier*. In cases where an expression is allowed, we'll
    prefer to use the pretty name, but in cases where we must use an identifier
    (e.g., when declaring a class), we must use the mangled name.

    To make code transformations easier, we'll create a bijection between
    pretty names and mangled names. Any disallowed character that might appear
    in a pretty name is mapped to an arcane unicode character in the mangled
    name. (Refer to the constants below for details.)

    See pretty_class_name() below for a demangling function to help display
    "pretty" class names to the user.
    """

    # This is the mangled substitution for "[" in a pretty name.
    # This letter is 'U+1D4E3 MATHEMATICAL BOLD SCRIPT CAPITAL T'.
    UNICODE_LEFT_BRACKET = "𝓣"

    # This is the mangled substitution for "]" in a pretty name.
    # This letter is 'U+1D4E4 MATHEMATICAL BOLD SCRIPT CAPITAL U'.
    UNICODE_RIGHT_BRACKET = "𝓤"

    # This is the mangled substitution for "," in a pretty name.
    # This letter is 'U+1D4EC MATHEMATICAL BOLD SCRIPT SMALL C'.
    UNICODE_COMMA = "𝓬"

    # This is the mangled substitution for "." in a pretty name.
    # This letter is 'U+1D4F9 MATHEMATICAL BOLD SCRIPT SMALL P'.
    UNICODE_PERIOD = "𝓹"

    @staticmethod
    def mangle(name: str) -> str:
        """Given a pretty name (or partially-mangled name), returns the
        corresponding fully-mangled name.

        For example, ``LeafSystem_[AutoDiffXd]`` as input becomes
        ``LeafSystem_𝓣AutoDiffXd𝓤`` as the return value.

        Names that do not need mangling (i.e., are already valid identifiers)
        are returned unchanged.

        If part of the name is already partially-mangled, it will remain so.
        For example, ``Image[PixelType𝓹kRgba8U]`` as input becomes
        ``Image𝓣PixelType𝓹kRgba8U𝓤`` as the return value. This implies
        that `demangle(mangle(name)) == name` does not always hold true.
        """
        name = name.replace("[", _MangledName.UNICODE_LEFT_BRACKET)
        name = name.replace("]", _MangledName.UNICODE_RIGHT_BRACKET)
        name = name.replace(",", _MangledName.UNICODE_COMMA)
        name = name.replace(".", _MangledName.UNICODE_PERIOD)
        # Sanity check that all of the characters are alpha-numeric (and
        # N.B. ignoring the rule that identifiers cannot start with numbers).
        assert ("_" + name).isidentifier(), name
        return name

    @staticmethod
    def demangle(name: str) -> str:
        """Given a mangled name, returns the pretty name."""
        name = name.replace(_MangledName.UNICODE_LEFT_BRACKET, "[")
        name = name.replace(_MangledName.UNICODE_RIGHT_BRACKET, "]")
        name = name.replace(_MangledName.UNICODE_COMMA, ",")
        name = name.replace(_MangledName.UNICODE_PERIOD, ".")
        return name

    @staticmethod
    def module_getattr(
        *,
        module_name: str,
        module_globals: typing.Mapping[str, typing.Any],
        name: str,
    ) -> typing.Any:
        """Looks up a name in a module's globals(), accounting for mangling.
        If the name is a pretty name, it's first converted to a mangled name.
        Then, the name is looked up in the module_globals.
        Unknown names are reported by raising an AttributeError.

        This function is intended to help implement __getattr__ on a module
        for backwards-compatibility with template unpickling vs prior versions
        of Drake.

        To make a module backwards-compatible with pickle loading, we place
        the following code into each module that contains any pre-v1.12.0
        pickled template classes.

        def __getattr__(name):
            return _MangledName.module_getattr(
                module_name=__name__, module_globals=globals(), name=name)

        Note that users cannot ``import`` names with, e.g., square brackets
        anyway. The renaming only comes into play for calls to ``getattr``,
        e.g., by the ``pickle`` module.
        """
        name = _MangledName.mangle(name)
        if name in module_globals:
            return module_globals[name]
        float_tag = "_{}float{}".format(
            _MangledName.UNICODE_LEFT_BRACKET,
            _MangledName.UNICODE_RIGHT_BRACKET,
        )
        if name.endswith(float_tag):
            shorter_name = name[: -len(float_tag)]
            if shorter_name in module_globals:
                return module_globals[shorter_name]
        raise AttributeError(
            f"module {module_name!r} has no attribute {name!r}"
        )


def pretty_class_name(cls: type, *, use_qualname: bool = False) -> str:
    """Given a class, returns its ``cls.__name__`` respelled to be suitable for
    display to a user, in particular by respelling C++ template arguments using
    their conventional ``FooBar_[AutoDiffXd]`` expression spelling instead of
    the mangled unicode name. Note that the returned name might not be a valid
    Python identifier, though it should still be a valid Python expression.

    If the class is not a template, simply returns ``cls.__name__`` unchanged.

    When ``use_qualname`` is true, uses ``cls.__qualname__`` instead of
    ``cls.__name__``.
    """
    if use_qualname:
        name = cls.__qualname__
    else:
        name = cls.__name__
    return _MangledName.demangle(name)


def _add_extraneous_repr_functions():
    """Defines repr functions for various classes in common where defining it
    in python is simply more convenient.
    """

    def mem_file_repr(file):
        # We only want to show the first k bytes. Showing the whole contents
        # wouldn't be practical and we assume that one can confirm the file
        # contents from the first 100 bytes or so.
        limit = 100
        if len(file.contents()) > limit:
            repr_contents = f"<{file.contents()[:limit]}...>"
        else:
            repr_contents = repr(file.contents())
        return (
            f"MemoryFile("
            f"contents={repr_contents}, "
            f"extension={repr(file.extension())}, "
            f"filename_hint={repr(file.filename_hint())})"
        )

    MemoryFile.__repr__ = mem_file_repr


_add_extraneous_repr_functions()

# We must be able to do `from pydrake.symbolic import _symbolic_sympy` so we
# need `pydrake.symbolic` to be a Python package, not merely a module. (See
# https://docs.python.org/3/tutorial/modules.html for details.) The way to
# designate something as a package is to define its `__path__` attribute.
__path__ = [sys.modules["pydrake"].__path__[0] + "/common"]



import matplotlib
import numpy as np

from pydrake.systems._resample_interp1d import _resample_interp1d
from pydrake.systems.framework import LeafSystem
from pydrake.systems.primitives import VectorLog
from pydrake.trajectories import Trajectory


class PyPlotVisualizer(LeafSystem):
    """
    Base class from planar visualization that relies on pyplot.

    In the configuration set up here, this visualizer provides one
    visualization window (self.fig) with axes (self.ax). The axes can
    optionally be supplied externally to allow other visualizers to overlay
    additional information.

    Subclasses must:
    - During initialization, set up the figure bounds and register input port
    with the appropriate message type.
    - Override the draw method to parse the input and draw the robot in the
    appropriate state.
    """

    def __init__(
        self,
        draw_period=None,
        facecolor=[1, 1, 1],
        figsize=None,
        ax=None,
        show=None,
    ):
        LeafSystem.__init__(self)

        # On Ubuntu the Debian package python3-tk is a recommended (but not
        # required) dependency of python3-matplotlib; help users understand
        # that by providing a nicer message upon a failure to import.
        try:
            import matplotlib.pyplot as plt

            self._plt = plt
        except ImportError as e:
            if e.name == "tkinter":
                self._plt = None
            else:
                raise
        if self._plt is None:
            raise NotImplementedError(
                "On Ubuntu when using the default pyplot configuration (i.e.,"
                " the TkAgg backend) you must 'sudo apt install python3-tk' to"
                " obtain Tk support. Alternatively, you may set MPLBACKEND to"
                " something else (e.g., Qt5Agg)."
            )

        # To help avoid small simulation time steps, we use a default period
        # that has an exact representation in binary floating point; see
        # drake#15021 for details.
        default_draw_period = 1.0 / 32

        self.set_name("pyplot_visualization")
        self.time_step = draw_period or default_draw_period
        self.DeclareForcedPublishEvent(self._on_any_publish)
        self.DeclarePeriodicPublishEvent(
            self.time_step, 0.0, self._on_any_publish
        )

        if ax is None:
            self.fig = self._plt.figure(facecolor=facecolor, figsize=figsize)
            self.ax = self._plt.axes()
            self.fig.add_axes(self.ax)
        else:
            self.ax = ax
            self.fig = ax.get_figure()

        if show is None:
            show = matplotlib.get_backend().lower() != "template"
        self._show = show

        self.ax.axis("equal")
        self.ax.axis("off")

        if not show:
            # This is the preferred way to support the jupyter notebook
            # animation workflow and the `inline` backend grabbing an
            # extraneous render of the figure.
            self._plt.close(self.fig)

        self._is_recording = False
        self._recorded_contexts = []

        def on_initialize(context):
            if self._show:
                self.fig.show()

        self.DeclareInitializationPublishEvent(on_initialize)
        self.DeclareInitializationPublishEvent(self._on_any_publish)

    def _on_any_publish(self, context):
        if self._show:
            self.draw(context)
            self.fig.canvas.draw()
            self._plt.pause(1e-10)
        if self._is_recording:
            snapshot = self.AllocateContext()
            snapshot.SetTimeStateAndParametersFrom(context)
            self.FixInputPortsFrom(self, context, snapshot)
            self._recorded_contexts.append(snapshot)

    def draw(self, context):
        """Draws a single frame.
        `context` can either be a Context object, or a raw vector (for ease of
        interpolation).
        """
        raise NotImplementedError

    def start_recording(self):
        self._is_recording = True

    def stop_recording(self):
        self._is_recording = False

    def reset_recording(self):
        self._recorded_contexts = []  # Reset recorded data.

    def _draw_recorded_frame(self, i):
        return self.draw(self._recorded_contexts[i])

    def get_recording_as_animation(self, **kwargs):
        # We defer this import to this call site to prevent the import
        # from hanging. See #18323.
        import matplotlib.animation as animation

        ani = animation.FuncAnimation(
            fig=self.fig,
            func=self._draw_recorded_frame,
            frames=len(self._recorded_contexts),
            interval=1000 * self.time_step,
            **kwargs,
        )
        return ani

    def animate(self, log, resample=True, **kwargs):
        """
        Args:
            log: A reference to a pydrake.systems.primitives.VectorLog, or a
                pydrake.trajectories.Trajectory that contains the plant state
                after running a simulation.
            resample: Whether we should do a resampling operation to make the
                samples more consistent in time. This can be disabled if you
                know the draw_period passed into the constructor exactly
                matches the sample time step of the log.
            Additional kwargs are passed through to FuncAnimation.
        """
        if isinstance(log, VectorLog):
            t = log.sample_times()
            x = log.data()

            if resample:
                t, x = _resample_interp1d(t, x, self.time_step)
        elif isinstance(log, Trajectory):
            t = np.arange(log.start_time(), log.end_time(), self.time_step)
            x = np.hstack([log.value(time) for time in t])

        def animate_update(i):
            self.draw(x[:, i])

        # We defer this import to this call site to prevent the import
        # from hanging. See #18323.
        import matplotlib.animation as animation

        ani = animation.FuncAnimation(
            fig=self.fig,
            func=animate_update,
            frames=t.shape[0],
            # Convert from s to ms.
            interval=1000 * self.time_step,
            **kwargs,
        )
        return ani



import numpy
import pydrake.geometry
import pydrake.lcm
import pydrake.math
import pydrake.multibody.plant
import pydrake.systems.framework
import pydrake.systems.lcm
import pydrake.systems.sensors
from pydrake.common.cpp_template import MeshcatPoseSliders_ as MeshcatPoseSliders_
from pydrake.visualization._meldis import Meldis as Meldis
from pydrake.visualization._model_visualizer import ModelVisualizer as ModelVisualizer
from pydrake.visualization._plotting import plot_sublevelset_expression as plot_sublevelset_expression, plot_sublevelset_quadratic as plot_sublevelset_quadratic
from pydrake.visualization._triad import AddFrameTriadIllustration as AddFrameTriadIllustration
from pydrake.visualization._video import VideoWriter as VideoWriter
from typing import ClassVar, overload

class ColorizeDepthImage(pydrake.systems.framework.LeafSystem):
    invalid_color: pydrake.geometry.Rgba
    def __init__(self) -> None: ...
    @overload
    def Calc(self, arg0: pydrake.systems.sensors.ImageTPixelTypepkDepth32FU, arg1: pydrake.systems.sensors.ImageTPixelTypepkRgba8UU) -> None: ...
    @overload
    def Calc(self, arg0: pydrake.systems.sensors.ImageTPixelTypepkDepth16UU, arg1: pydrake.systems.sensors.ImageTPixelTypepkRgba8UU) -> None: ...

class ColorizeLabelImage(pydrake.systems.framework.LeafSystem):
    background_color: pydrake.geometry.Rgba
    def __init__(self) -> None: ...
    def Calc(self, arg0: pydrake.systems.sensors.ImageTPixelTypepkLabel16IU, arg1: pydrake.systems.sensors.ImageTPixelTypepkRgba8UU) -> None: ...

class ConcatenateImages(pydrake.systems.framework.LeafSystem):
    def __init__(self, rows: int = ..., cols: int = ...) -> None: ...
    def get_input_port(self, row: int, col: int) -> pydrake.systems.framework.InputPort: ...

class MeshcatPoseSliders(pydrake.systems.framework.LeafSystem):
    def __init__(self, meshcat: pydrake.geometry.Meshcat, initial_pose: pydrake.math.RigidTransform = ..., lower_limit: numpy.ndarray[numpy.float64[6, 1]] = ..., upper_limit: numpy.ndarray[numpy.float64[6, 1]] = ..., step: numpy.ndarray[numpy.float64[6, 1]] = ..., decrement_keycodes: list[str] = ..., increment_keycodes: list[str] = ..., prefix: str = ..., visible: numpy.ndarray[bool[6, 1]] = ...) -> None: ...
    def Delete(self) -> None: ...
    def Run(self, system: pydrake.systems.framework.System, context: pydrake.systems.framework.Context, timeout: float | None = ..., stop_button_keycode: str = ...) -> pydrake.math.RigidTransform: ...
    def SetPose(self, pose: pydrake.math.RigidTransform) -> None: ...

class MeshcatPoseSliders_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, meshcat: pydrake.geometry.Meshcat, initial_pose: pydrake.math.RigidTransform = ..., lower_limit: numpy.ndarray[numpy.float64[6, 1]] = ..., upper_limit: numpy.ndarray[numpy.float64[6, 1]] = ..., step: numpy.ndarray[numpy.float64[6, 1]] = ..., decrement_keycodes: list[str] = ..., increment_keycodes: list[str] = ..., prefix: str = ..., visible: numpy.ndarray[bool[6, 1]] = ...) -> None: ...
    def Delete(self) -> None: ...
    def Run(self, system: pydrake.systems.framework.System_TAutoDiffXdU, context: pydrake.systems.framework.Context_TAutoDiffXdU, timeout: float | None = ..., stop_button_keycode: str = ...) -> pydrake.math.RigidTransform: ...
    def SetPose(self, pose: pydrake.math.RigidTransform) -> None: ...

class VisualizationConfig:
    __fields__: ClassVar[tuple] = ...  # read-only
    default_illustration_color: pydrake.geometry.Rgba
    default_proximity_color: pydrake.geometry.Rgba
    delete_on_initialization_event: bool
    enable_alpha_sliders: bool
    enable_meshcat_creation: bool
    initial_proximity_alpha: float
    lcm_bus: str
    publish_contacts: bool
    publish_illustration: bool
    publish_inertia: bool
    publish_period: float
    publish_proximity: bool
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> VisualizationConfig: ...
    def __deepcopy__(self, arg0: dict) -> VisualizationConfig: ...

class _TemporaryName_N5drake13visualization18MeshcatPoseSlidersINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, meshcat: pydrake.geometry.Meshcat, initial_pose: pydrake.math.RigidTransform = ..., lower_limit: numpy.ndarray[numpy.float64[6, 1]] = ..., upper_limit: numpy.ndarray[numpy.float64[6, 1]] = ..., step: numpy.ndarray[numpy.float64[6, 1]] = ..., decrement_keycodes: list[str] = ..., increment_keycodes: list[str] = ..., prefix: str = ..., visible: numpy.ndarray[bool[6, 1]] = ...) -> None: ...
    def Delete(self) -> None: ...
    def Run(self, system: pydrake.systems.framework.System_TAutoDiffXdU, context: pydrake.systems.framework.Context_TAutoDiffXdU, timeout: float | None = ..., stop_button_keycode: str = ...) -> pydrake.math.RigidTransform: ...
    def SetPose(self, pose: pydrake.math.RigidTransform) -> None: ...

def AddDefaultVisualization(builder: pydrake.systems.framework.DiagramBuilder, meshcat: pydrake.geometry.Meshcat = ...) -> None: ...
def ApplyVisualizationConfig(config: VisualizationConfig, builder: pydrake.systems.framework.DiagramBuilder, lcm_buses: pydrake.systems.lcm.LcmBuses = ..., plant: pydrake.multibody.plant.MultibodyPlant = ..., scene_graph: pydrake.geometry.SceneGraph = ..., meshcat: pydrake.geometry.Meshcat = ..., lcm: pydrake.lcm.DrakeLcmInterface = ...) -> None: ...



"""LCM type definitions
This file automatically generated by lcm.
DO NOT MODIFY BY HAND!!!!
"""


from io import BytesIO
import struct

class lcmt_drake_signal(object):
    """
    This LCM message contains a basic vector of doubles that can represent any
    signal passed around in Drake. Note that the channel name on which this
    message is sent will represent the name of the overall signal.
    """

    __slots__ = ["dim", "val", "coord", "timestamp"]

    __typenames__ = ["int32_t", "double", "string", "int64_t"]

    __dimensions__ = [None, ["dim"], ["dim"], None]

    def __init__(self):
        self.dim = 0
        """
        The number of elements in the signal.
        LCM Type: int32_t
        """

        self.val = []
        """
        The value of each element in the signal.
        LCM Type: double[dim]
        """

        self.coord = []
        """
        The name of each element in the signal.
        LCM Type: string[dim]
        """

        self.timestamp = 0
        """
        The timestamp in milliseconds.
        LCM Type: int64_t
        """


    def encode(self):
        buf = BytesIO()
        buf.write(lcmt_drake_signal._get_packed_fingerprint())
        self._encode_one(buf)
        return buf.getvalue()

    def _encode_one(self, buf):
        buf.write(struct.pack(">i", self.dim))
        buf.write(struct.pack('>%dd' % self.dim, *self.val[:self.dim]))
        for i0 in range(self.dim):
            __coord_encoded = self.coord[i0].encode('utf-8')
            buf.write(struct.pack('>I', len(__coord_encoded)+1))
            buf.write(__coord_encoded)
            buf.write(b"\0")
        buf.write(struct.pack(">q", self.timestamp))

    @staticmethod
    def decode(data: bytes):
        if hasattr(data, 'read'):
            buf = data
        else:
            buf = BytesIO(data)
        if buf.read(8) != lcmt_drake_signal._get_packed_fingerprint():
            raise ValueError("Decode error")
        return lcmt_drake_signal._decode_one(buf)

    @staticmethod
    def _decode_one(buf):
        self = lcmt_drake_signal()
        self.dim = struct.unpack(">i", buf.read(4))[0]
        self.val = struct.unpack('>%dd' % self.dim, buf.read(self.dim * 8))
        self.coord = []
        for i0 in range(self.dim):
            __coord_len = struct.unpack('>I', buf.read(4))[0]
            self.coord.append(buf.read(__coord_len)[:-1].decode('utf-8', 'replace'))
        self.timestamp = struct.unpack(">q", buf.read(8))[0]
        return self

    @staticmethod
    def _get_hash_recursive(parents):
        if lcmt_drake_signal in parents: return 0
        tmphash = (0x236e73ecd6fc3932) & 0xffffffffffffffff
        tmphash  = (((tmphash<<1)&0xffffffffffffffff) + (tmphash>>63)) & 0xffffffffffffffff
        return tmphash
    _packed_fingerprint = None

    @staticmethod
    def _get_packed_fingerprint():
        if lcmt_drake_signal._packed_fingerprint is None:
            lcmt_drake_signal._packed_fingerprint = struct.pack(">Q", lcmt_drake_signal._get_hash_recursive([]))
        return lcmt_drake_signal._packed_fingerprint

    def get_hash(self):
        """Get the LCM hash of the struct"""
        return struct.unpack(">Q", lcmt_drake_signal._get_packed_fingerprint())[0]




from . import acrobot as acrobot, all as all

class MassDamperSpringAnalyticalSolution:
    def __init__(self, mass: float, b: float, k: float) -> None: ...
    def SetInitialValue(self, x0: float, xDt0: float) -> None: ...
    def get_x(self, t: float) -> float: ...
    def get_xDt(self, t: float) -> float: ...
    def get_xDtDt(self, t: float) -> float: ...



# See `ExecuteExtraPythonCode` in `pydrake_pybind.h` for usage details and
# rationale.

# ruff: noqa: F821 (undefined-name). This file is only a fragment.

import os
import socket
import subprocess
import sys


def _is_listening(port):
    """Returns True iff the port number (on localhost) is listening for
    connections.
    """
    try:
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        return sock.connect_ex(("127.0.0.1", port)) == 0
    finally:
        sock.close()


def _restart_nginx_service():
    """(Re)starts Drake Deepnote's nginx proxy."""
    print("(Re)starting NginX server for MeshCat on Deepnote...")
    proc = subprocess.run(
        ["service", "nginx", "restart"],
        encoding="utf-8",
        stdout=subprocess.PIPE,
        stderr=subprocess.STDOUT,
    )
    if proc.returncode == 0:
        return
    print(proc.stdout, file=sys.stderr, end="")
    proc.check_returncode()


def _start_meshcat_deepnote(*, params=None, restart_nginx=False):
    """Returns a Meshcat object suitable for use on Deepnote's cloud.
    The optional arguments are not available to end users but might be helpful
    when debugging this function.
    """
    from IPython.display import HTML, display

    host = os.environ["DEEPNOTE_PROJECT_ID"]
    if params is None:
        params = MeshcatParams()
    params.web_url_pattern = f"https://{host}.deepnoteproject.com/{{port}}/"
    if restart_nginx or not _is_listening(8080):
        _restart_nginx_service()
    meshcat = Meshcat(params=params)
    url = meshcat.web_url()
    display(HTML(f"Meshcat URL: <a href='{url}' target='_blank'>{url}</a>"))
    return meshcat


def StartMeshcat():
    """
    Constructs a Meshcat instance, with extra support for Deepnote.

    On most platforms, this function is equivalent to simply constructing a
    ``pydrake.geometry.Meshcat`` object with default arguments.

    On Deepnote, however, this does extra work to expose Meshcat to the public
    internet by setting up a reverse proxy for the single available network
    port. To access it, you must enable "Allow incoming connections" in the
    Environment settings pane.
    """
    if "DEEPNOTE_PROJECT_ID" in os.environ:
        return _start_meshcat_deepnote()
    return Meshcat()


def _add_extraneous_repr_functions():
    """Defines repr functions for various classes in common where defining it
    in python is simply more convenient.
    """

    def in_memory_mesh_repr(mesh):
        # If defined, the supporting string has to provide the preceding comma,
        # and space, along with the parameter name and its value.
        supporting_string = ""
        if mesh.supporting_files:
            supporting_string = (
                f", supporting_files={repr(mesh.supporting_files)}"
            )
        return (
            f"InMemoryMesh(mesh_file={repr(mesh.mesh_file)}{supporting_string})"
        )

    InMemoryMesh.__repr__ = in_memory_mesh_repr

    def mesh_source_repr(source):
        if source.is_path():
            param_str = f"path={repr(str(source.path()))}"
        else:
            param_str = f"mesh={repr(source.in_memory())}"
        return f"MeshSource({param_str})"

    MeshSource.__repr__ = mesh_source_repr

    def mesh_or_convex_repr(mesh, type_name):
        if mesh.source().is_path():
            data_param = f"filename={repr(str(mesh.source().path()))}"
        else:
            data_param = f"mesh_data={repr(mesh.source().in_memory())}"
        # Convert array to list to ease converting repr to mesh type.
        return (
            f"{type_name}({data_param}, scale3={repr(mesh.scale3().tolist())})"
        )

    Mesh.__repr__ = lambda x: mesh_or_convex_repr(x, "Mesh")
    Convex.__repr__ = lambda x: mesh_or_convex_repr(x, "Convex")


_add_extraneous_repr_functions()



# See `ExecuteExtraPythonCode` in `pydrake_pybind.h` for usage details and
# rationale.

# ruff: noqa: F821 (undefined-name). This file is only a fragment.

from pydrake.common.cpp_param import List


def _AbstractValue_Make(value):
    """Returns an AbstractValue containing the given ``value``.
    The factory method ``AbstractValue.Make(value)`` and the constructor
    ``Value(value)`` are equivalent."""
    if isinstance(value, list) and len(value) > 0:
        inner_cls = type(value[0])
        cls = List[inner_cls]
    else:
        cls = type(value)
    value_cls, _ = Value.get_instantiation(cls, throw_error=False)
    if value_cls is None:
        value_cls = Value[object]
    return value_cls(value)


AbstractValue.Make = _AbstractValue_Make

# Adjust how type inference works for Value(some_value). We want to use the
# precise semantics of AbstractValue.Make, not the anything-goes TemplateBase.
setattr(Value, "_call_internal", _AbstractValue_Make)



"""LCM type definitions
This file automatically generated by lcm.
DO NOT MODIFY BY HAND!!!!
"""


from io import BytesIO
import struct

import drake

class lcmt_viewer_load_robot(object):

    __slots__ = ["num_links", "link"]

    __typenames__ = ["int32_t", "drake.lcmt_viewer_link_data"]

    __dimensions__ = [None, ["num_links"]]

    def __init__(self):
        self.num_links = 0
        """ LCM Type: int32_t """
        self.link = []
        """ LCM Type: drake.lcmt_viewer_link_data[num_links] """

    def encode(self):
        buf = BytesIO()
        buf.write(lcmt_viewer_load_robot._get_packed_fingerprint())
        self._encode_one(buf)
        return buf.getvalue()

    def _encode_one(self, buf):
        buf.write(struct.pack(">i", self.num_links))
        for i0 in range(self.num_links):
            assert self.link[i0]._get_packed_fingerprint() == drake.lcmt_viewer_link_data._get_packed_fingerprint()
            self.link[i0]._encode_one(buf)

    @staticmethod
    def decode(data: bytes):
        if hasattr(data, 'read'):
            buf = data
        else:
            buf = BytesIO(data)
        if buf.read(8) != lcmt_viewer_load_robot._get_packed_fingerprint():
            raise ValueError("Decode error")
        return lcmt_viewer_load_robot._decode_one(buf)

    @staticmethod
    def _decode_one(buf):
        self = lcmt_viewer_load_robot()
        self.num_links = struct.unpack(">i", buf.read(4))[0]
        self.link = []
        for i0 in range(self.num_links):
            self.link.append(drake.lcmt_viewer_link_data._decode_one(buf))
        return self

    @staticmethod
    def _get_hash_recursive(parents):
        if lcmt_viewer_load_robot in parents: return 0
        newparents = parents + [lcmt_viewer_load_robot]
        tmphash = (0x739e6927d8bcec39+ drake.lcmt_viewer_link_data._get_hash_recursive(newparents)) & 0xffffffffffffffff
        tmphash  = (((tmphash<<1)&0xffffffffffffffff) + (tmphash>>63)) & 0xffffffffffffffff
        return tmphash
    _packed_fingerprint = None

    @staticmethod
    def _get_packed_fingerprint():
        if lcmt_viewer_load_robot._packed_fingerprint is None:
            lcmt_viewer_load_robot._packed_fingerprint = struct.pack(">Q", lcmt_viewer_load_robot._get_hash_recursive([]))
        return lcmt_viewer_load_robot._packed_fingerprint

    def get_hash(self):
        """Get the LCM hash of the struct"""
        return struct.unpack(">Q", lcmt_viewer_load_robot._get_packed_fingerprint())[0]




r"""Utility for fixing invalid inertia data in URDF or SDFormat files, by
writing a complete, updated file.

Inertia properties for links are inferred from geometry. Only the file
supplied as an input is updated; any included or referred-to files are left
untouched. The inferred geometry for each body is determined by the first role
which has geometry defined. The roles are visited in the order specified by
--geom_inertia_role_order, whose default order is
"proximity illustration perception".

The output file should differ from the input file only by the contents of
`<inertial>` tags. It is possible that some comments may be lost within those
tags.

**Running**:

    From a Drake source build, run this as::

            bazel run //tools:fix_inertia -- --help

    From a Drake binary release (including pip releases), run this as::

            python3 -m pydrake.multibody.fix_inertia --help

    Run with output to the standard output::

            bazel run //tools:fix_inertia -- path/to/some_model.urdf

    Run with output to a separate file::

            bazel run //tools:fix_inertia -- \
                path/to/some_model.urdf output.urdf

    Run with output overwriting the input file (sometimes convenient within a
    source code control workspace)::

            bazel run //tools:fix_inertia -- --in_place path/to/some_model.urdf

    This program respects the ROS_PACKAGE_PATH; if your model uses external
    resources then you will need to set that environment variable.

**Using the results**:

    The output file will be well-formed XML and parse cleanly in Drake, but it
    may not be exactly suited to the purpose at hand. Be sure to examine the
    model file differences, and use `model_visualizer` to examine the resulting
    inertial ellipsoids.

    See `model_visualizer` documentation here:
    https://drake.mit.edu/pydrake/pydrake.visualization.model_visualizer.html

    Once the effect of the changes is clear, either use the new output file
    as-is, or merge in the desired changes using any text file merging tool.

"""

import argparse
import os

from pydrake.common import configure_logging as _configure_logging
from pydrake.multibody import _inertia_fixer


def _main():
    _configure_logging()
    geom_inertia_role_order_str_default = _inertia_fixer.role_list_to_str_list(
        _inertia_fixer.GEOM_INERTIA_ROLE_ORDER_DEFAULT
    )
    geom_role_choices_str = _inertia_fixer.role_list_to_str_list(
        _inertia_fixer.GEOM_INERTIA_ROLE_AVAILABLE
    )

    parser = argparse.ArgumentParser(
        description=__doc__,
        formatter_class=argparse.RawDescriptionHelpFormatter,
    )
    parser.add_argument(
        "input_file",
        type=str,
        help="Filesystem path to an SDFormat or URDF file.",
    )
    parser.add_argument(
        "output_file",
        type=str,
        nargs="?",
        help="[Optional] Filesystem path to write output with repaired"
        " inertias. If missing, output will go to stdout.",
    )
    parser.add_argument(
        "--in_place",
        action="store_true",
        help="Modify the input file in-place. Any output_file argument"
        " will be ignored.",
    )
    parser.add_argument(
        "--geom_inertia_role_order",
        type=str,
        nargs="+",
        choices=geom_role_choices_str,
        default=geom_inertia_role_order_str_default,
    )
    args = parser.parse_args()

    if "BUILD_WORKSPACE_DIRECTORY" in os.environ:
        os.chdir(os.environ["BUILD_WORKING_DIRECTORY"])

    geom_inertia_role_order = _inertia_fixer.str_list_to_role_list(
        args.geom_inertia_role_order
    )
    fixer = _inertia_fixer.InertiaFixer(
        input_file=args.input_file,
        output_file=args.output_file,
        in_place=args.in_place,
        geom_inertia_role_order=geom_inertia_role_order,
    )
    fixer.fix_inertia()


if __name__ == "__main__":
    _main()



# ruff: noqa: F821 (undefined-name). This file is only a fragment.

from pydrake.common import (
    _MangledName,
)
from pydrake.common import (
    pretty_class_name as _pretty_class_name,
)


def __getattr__(name):
    """Rewrites requests for Foo[bar] into their mangled form, for backwards
    compatibility with unpickling.
    """
    return _MangledName.module_getattr(
        module_name=__name__, module_globals=globals(), name=name
    )


def _wrapped_trajectory_repr(wrapped_trajectory):
    cls = type(wrapped_trajectory)
    return f"{_pretty_class_name(cls)}({wrapped_trajectory.unwrap()!r})"


def _add_repr_functions():
    for param in _WrappedTrajectory_.param_list:
        cls = _WrappedTrajectory_[param]
        setattr(cls, "__repr__", _wrapped_trajectory_repr)


_add_repr_functions()
